pub struct CPAlertAction { /* private fields */ }CPAlertAction only.Expand description
CPAlertActionrepresents a single action that appears inside of a
CPActionSheetTemplateor
CPAlertTemplate.
The style of the parent template and the style of the
CPAlertActionwill together
determine the action’s appearance.
The action has a customizable title, style, and a block callback that is invoked when the user taps this button.
See also Apple’s documentation
Implementations
Sourceimpl CPAlertAction
impl CPAlertAction
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new() -> Retained<Self>
Sourcepub unsafe fn initWithTitle_style_handler(
this: Allocated<Self>,
title: &NSString,
style: CPAlertActionStyle,
handler: CPAlertActionHandler,
) -> Retained<Self>
Available on crate feature block2 only.
pub unsafe fn initWithTitle_style_handler( this: Allocated<Self>, title: &NSString, style: CPAlertActionStyle, handler: CPAlertActionHandler, ) -> Retained<Self>
block2 only.Create an alert action with a title, display style, and a callback handler that is invoked when the user taps this action.
Safety
handler must be a valid pointer.
Sourcepub unsafe fn initWithTitle_color_handler(
this: Allocated<Self>,
title: &NSString,
color: &UIColor,
handler: CPAlertActionHandler,
) -> Retained<Self>
Available on crate features block2 and objc2-ui-kit only.
pub unsafe fn initWithTitle_color_handler( this: Allocated<Self>, title: &NSString, color: &UIColor, handler: CPAlertActionHandler, ) -> Retained<Self>
block2 and objc2-ui-kit only.Create an alert action with a title, a custom action color, and a callback handler that is invoked when the user taps this action.
The system will automatically determine if the provided color meets contrast requirements. If the provided color does not meet contrast requirements, the system default will be used. Font color will automatically be adjusted by the system to correspond with this color. Alpha values will be ignored.
Safety
handler must be a valid pointer.
pub unsafe fn title(&self) -> Retained<NSString>
pub unsafe fn style(&self) -> CPAlertActionStyle
Sourcepub unsafe fn handler(&self) -> CPAlertActionHandler
Available on crate feature block2 only.
pub unsafe fn handler(&self) -> CPAlertActionHandler
block2 only.Safety
The returned block’s argument must be a valid pointer.
pub unsafe fn color(&self) -> Option<Retained<UIColor>>
objc2-ui-kit only.Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for CPAlertAction
impl AsRef<AnyObject> for CPAlertAction
Sourceimpl AsRef<CPAlertAction> for CPAlertAction
impl AsRef<CPAlertAction> for CPAlertAction
Sourceimpl AsRef<NSObject> for CPAlertAction
impl AsRef<NSObject> for CPAlertAction
Sourceimpl Borrow<AnyObject> for CPAlertAction
impl Borrow<AnyObject> for CPAlertAction
Sourceimpl Borrow<NSObject> for CPAlertAction
impl Borrow<NSObject> for CPAlertAction
Sourceimpl ClassType for CPAlertAction
impl ClassType for CPAlertAction
Sourceconst NAME: &'static str = "CPAlertAction"
const NAME: &'static str = "CPAlertAction"
Sourcetype ThreadKind = <<CPAlertAction as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<CPAlertAction as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for CPAlertAction
impl Debug for CPAlertAction
Sourceimpl Deref for CPAlertAction
impl Deref for CPAlertAction
Sourceimpl Hash for CPAlertAction
impl Hash for CPAlertAction
Sourceimpl Message for CPAlertAction
impl Message for CPAlertAction
Sourceimpl NSCoding for CPAlertAction
impl NSCoding for CPAlertAction
Sourceimpl NSObjectProtocol for CPAlertAction
impl NSObjectProtocol for CPAlertAction
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref