CPBarButton

Struct CPBarButton 

pub struct CPBarButton { /* private fields */ }
Available on crate feature CPBarButton only.
A button for placement in a navigation bar.

See also Apple’s documentation

Implementations

Source

impl CPBarButton

pub unsafe fn new() -> Retained<Self>

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn initWithImage_handler( this: Allocated<Self>, image: &UIImage, handler: CPBarButtonHandler, ) -> Retained<Self>

Available on crate features block2 and objc2-ui-kit only.

Convenience initializer that creates a bar button that renders with an image.

Safety

handler must be a valid pointer or null.

pub unsafe fn initWithTitle_handler( this: Allocated<Self>, title: &NSString, handler: CPBarButtonHandler, ) -> Retained<Self>

Available on crate feature block2 only.

Convenience initializer that creates a bar button that displays a text label.

Safety

handler must be a valid pointer or null.

pub unsafe fn isEnabled(&self) -> bool

A Boolean value indicating whether the button is enabled.

Set the value of this property to YESto enable the button or NOto disable it. The default value of this property is YES.

pub unsafe fn setEnabled(&self, enabled: bool)

Setter for isEnabled.

pub unsafe fn buttonStyle(&self) -> CPBarButtonStyle

The style used to display this button.

Defaults to CPBarButtonStyleNone.

pub unsafe fn setButtonStyle(&self, button_style: CPBarButtonStyle)

Setter for buttonStyle.

pub unsafe fn image(&self) -> Option<Retained<UIImage>>

Available on crate feature objc2-ui-kit only.

The image displayed on the button.

Animated images are not supported. If an animated image is assigned, only the first image will be used.

Note: If both an image and title are specified, the title will take precedence. To use an image, ensure that the button’s title is nil.

pub unsafe fn setImage(&self, image: Option<&UIImage>)

Available on crate feature objc2-ui-kit only.

Setter for image.

pub unsafe fn title(&self) -> Option<Retained<NSString>>

The title displayed on the button.

Note: If both an image and title are specified, the title will take precedence. To use an image, ensure that the button’s title is nil.

pub unsafe fn setTitle(&self, title: Option<&NSString>)

Setter for title.

This is copied when set.

pub unsafe fn initWithType_handler( this: Allocated<Self>, type: CPBarButtonType, handler: CPBarButtonHandler, ) -> Retained<Self>

👎Deprecated
Available on crate feature block2 only.
Safety

handler must be a valid pointer or null.

pub unsafe fn buttonType(&self) -> CPBarButtonType

👎Deprecated

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}