pub struct CPContactDirectionsButton { /* private fields */ }CPButton and CPContact only.Expand description
Implementations
Sourceimpl CPContactDirectionsButton
impl CPContactDirectionsButton
Sourcepub unsafe fn initWithHandler(
this: Allocated<Self>,
handler: Option<&DynBlock<dyn Fn(NonNull<CPButton>)>>,
) -> Retained<Self>
Available on crate feature block2 only.
pub unsafe fn initWithHandler( this: Allocated<Self>, handler: Option<&DynBlock<dyn Fn(NonNull<CPButton>)>>, ) -> Retained<Self>
block2 only.Create a contact button with a system-provided navigation directions image that, when tapped, calls your custom handler.
Parameter handler: A block that will be called when the user taps this button.
pub unsafe fn initWithImage_handler( this: Allocated<Self>, image: &UIImage, handler: Option<&DynBlock<dyn Fn(NonNull<CPButton>)>>, ) -> Retained<Self>
block2 and objc2-ui-kit only.Methods from Deref<Target = CPButton>
Sourcepub unsafe fn image(&self) -> Option<Retained<UIImage>>
Available on crate feature objc2-ui-kit only.
pub unsafe fn image(&self) -> Option<Retained<UIImage>>
objc2-ui-kit only.An optional image, displayed only in templates that support custom images, like the Contact template.
When providing an image, your app should provide a
UIImagethat is display-ready. If necessary for the image, provide
light and dark styles by using an asset from your asset catalog, prepared with light and dark styles
or by using
UIImageAssetto combine two
UIImageinstances into a single image with
both styles.
UIImageAsset is used to combine multiple UIImages with different trait collections into a single UIImage.
Sourcepub unsafe fn title(&self) -> Option<Retained<NSString>>
pub unsafe fn title(&self) -> Option<Retained<NSString>>
A custom title to display for this button, displayed only in templates that allow for custom titles.
Sourcepub unsafe fn isEnabled(&self) -> bool
pub unsafe fn isEnabled(&self) -> bool
A Boolean value indicating whether the button is enabled.
Set the value of this property to
YESto enable the button or
NOto disable it. The default value of this property is
YES.
Sourcepub unsafe fn setEnabled(&self, enabled: bool)
pub unsafe fn setEnabled(&self, enabled: bool)
Setter for isEnabled.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for CPContactDirectionsButton
impl AsRef<AnyObject> for CPContactDirectionsButton
Sourceimpl AsRef<CPButton> for CPContactDirectionsButton
impl AsRef<CPButton> for CPContactDirectionsButton
Sourceimpl AsRef<NSObject> for CPContactDirectionsButton
impl AsRef<NSObject> for CPContactDirectionsButton
Sourceimpl Borrow<AnyObject> for CPContactDirectionsButton
impl Borrow<AnyObject> for CPContactDirectionsButton
Sourceimpl Borrow<CPButton> for CPContactDirectionsButton
impl Borrow<CPButton> for CPContactDirectionsButton
Sourceimpl Borrow<NSObject> for CPContactDirectionsButton
impl Borrow<NSObject> for CPContactDirectionsButton
Sourceimpl ClassType for CPContactDirectionsButton
impl ClassType for CPContactDirectionsButton
Sourceconst NAME: &'static str = "CPContactDirectionsButton"
const NAME: &'static str = "CPContactDirectionsButton"
Sourcetype ThreadKind = <<CPContactDirectionsButton as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<CPContactDirectionsButton as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for CPContactDirectionsButton
impl Debug for CPContactDirectionsButton
Sourceimpl Deref for CPContactDirectionsButton
impl Deref for CPContactDirectionsButton
Sourceimpl Hash for CPContactDirectionsButton
impl Hash for CPContactDirectionsButton
Sourceimpl Message for CPContactDirectionsButton
impl Message for CPContactDirectionsButton
Sourceimpl NSObjectProtocol for CPContactDirectionsButton
impl NSObjectProtocol for CPContactDirectionsButton
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref