CPContactMessageButton

Struct CPContactMessageButton 

pub struct CPContactMessageButton { /* private fields */ }
Available on crate features CPButton and CPContact only.
Implementations

Source

impl CPContactMessageButton

pub unsafe fn initWithPhoneOrEmail( this: Allocated<Self>, phone_or_email: &NSString, ) -> Retained<Self>

Create a contact button that, when tapped, launches to Siri to compose a message to this entity. When tapped, this button does NOT call a handler in your app. Instead, it will launch to Siri. To compose a message, you must provide a phone OR email for this contact.

Parameter phoneOrEmail: A phone or email address for this contact. This will not be displayed in the button, but it is necessary for Siri to compose a message to this contact entity.

pub unsafe fn phoneOrEmail(&self) -> Retained<NSString>

Source

impl CPContactMessageButton

Methods declared on superclass CPButton.

pub unsafe fn initWithImage_handler( this: Allocated<Self>, image: &UIImage, handler: Option<&DynBlock<dyn Fn(NonNull<CPButton>)>>, ) -> Retained<Self>

Available on crate features block2 and objc2-ui-kit only.

Initialize a button for the Contact, POI, or Information templates with a custom image and a handler, called when the user taps this button.

Parameter image: An image to be displayed in this button. The maximum image size is given by CPButtonMaximumImageSize. Parameter handler: A block that will be called when the user taps this button.

Note: This class is only available in templates that support buttons with custom images, like the Contact template.

When providing an image, your app should provide a UIImagethat is display-ready. If necessary for the image, provide light and dark styles by using an asset from your asset catalog, prepared with light and dark styles or by using UIImageAssetto combine two UIImageinstances into a single image with both styles.

UIImageAsset is used to combine multiple UIImages with different trait collections into a single UIImage.

pub unsafe fn new() -> Retained<Self>

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

Methods from Deref<Target = CPButton>

pub unsafe fn image(&self) -> Option<Retained<UIImage>>

Available on crate feature objc2-ui-kit only.

An optional image, displayed only in templates that support custom images, like the Contact template.

When providing an image, your app should provide a UIImagethat is display-ready. If necessary for the image, provide light and dark styles by using an asset from your asset catalog, prepared with light and dark styles or by using UIImageAssetto combine two UIImageinstances into a single image with both styles.

UIImageAsset is used to combine multiple UIImages with different trait collections into a single UIImage.

pub unsafe fn title(&self) -> Option<Retained<NSString>>

A custom title to display for this button, displayed only in templates that allow for custom titles.

pub unsafe fn setTitle(&self, title: Option<&NSString>)

Setter for title.

This is copied when set.

pub unsafe fn isEnabled(&self) -> bool

A Boolean value indicating whether the button is enabled.

Set the value of this property to YESto enable the button or NOto disable it. The default value of this property is YES.

pub unsafe fn setEnabled(&self, enabled: bool)

Setter for isEnabled.

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}