pub struct CPDashboardButton { /* private fields */ }CPDashboardButton only.Expand description
Implementations
Sourceimpl CPDashboardButton
impl CPDashboardButton
pub unsafe fn new() -> Retained<Self>
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourcepub unsafe fn initWithTitleVariants_subtitleVariants_image_handler(
this: Allocated<Self>,
title_variants: &NSArray<NSString>,
subtitle_variants: &NSArray<NSString>,
image: &UIImage,
handler: Option<&DynBlock<dyn Fn(NonNull<CPDashboardButton>)>>,
) -> Retained<Self>
Available on crate features block2 and objc2-ui-kit only.
pub unsafe fn initWithTitleVariants_subtitleVariants_image_handler( this: Allocated<Self>, title_variants: &NSArray<NSString>, subtitle_variants: &NSArray<NSString>, image: &UIImage, handler: Option<&DynBlock<dyn Fn(NonNull<CPDashboardButton>)>>, ) -> Retained<Self>
block2 and objc2-ui-kit only.Initialize a button with title variants, optional subtitle variants, and image.
Parameter titleVariants: An array of title variants for this button, arranged from longest to shortest. You must provide at least one title.
Parameter subtitleVariants: An array of subtitle variants for this button, arranged from longest to shortest.
Parameter image: The image displayed on the button. It must be non-nil for the button to be displayed.
Parameter handler: A block to execute when the user selects the button. The block has no return value and takes the selected button as its only parameter.
The image must be non-nil and the title must be a non-zero length string for the button to be displayed.
Sourcepub unsafe fn image(&self) -> Retained<UIImage>
Available on crate feature objc2-ui-kit only.
pub unsafe fn image(&self) -> Retained<UIImage>
objc2-ui-kit only.The image displayed on the button. Maximum supported size is 30x30 points.
Animated images are not supported. If an animated image is assigned, only the first image will be used.
Sourcepub unsafe fn titleVariants(&self) -> Retained<NSArray<NSString>>
pub unsafe fn titleVariants(&self) -> Retained<NSArray<NSString>>
An array of title variants for this button, arranged from most to least preferred. The system will select a title from your list of provided variants that fits the available space. The variant strings should be provided as localized, displayable content.
Sourcepub unsafe fn subtitleVariants(&self) -> Retained<NSArray<NSString>>
pub unsafe fn subtitleVariants(&self) -> Retained<NSArray<NSString>>
An array of subtitle variants for this button, arranged from most to least preferred. The system will select a title from your list of provided variants that fits the available space. The variant strings should be provided as localized, displayable content.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for CPDashboardButton
impl AsRef<AnyObject> for CPDashboardButton
Sourceimpl AsRef<CPDashboardButton> for CPDashboardButton
impl AsRef<CPDashboardButton> for CPDashboardButton
Sourceimpl AsRef<NSObject> for CPDashboardButton
impl AsRef<NSObject> for CPDashboardButton
Sourceimpl Borrow<AnyObject> for CPDashboardButton
impl Borrow<AnyObject> for CPDashboardButton
Sourceimpl Borrow<NSObject> for CPDashboardButton
impl Borrow<NSObject> for CPDashboardButton
Sourceimpl ClassType for CPDashboardButton
impl ClassType for CPDashboardButton
Sourceconst NAME: &'static str = "CPDashboardButton"
const NAME: &'static str = "CPDashboardButton"
Sourcetype ThreadKind = <<CPDashboardButton as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<CPDashboardButton as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for CPDashboardButton
impl Debug for CPDashboardButton
Sourceimpl Deref for CPDashboardButton
impl Deref for CPDashboardButton
Sourceimpl Hash for CPDashboardButton
impl Hash for CPDashboardButton
Sourceimpl Message for CPDashboardButton
impl Message for CPDashboardButton
Sourceimpl NSCoding for CPDashboardButton
impl NSCoding for CPDashboardButton
Sourceimpl NSObjectProtocol for CPDashboardButton
impl NSObjectProtocol for CPDashboardButton
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref