pub struct CPGridButton { /* private fields */ }CPGridButton only.Expand description
Implementations
Sourceimpl CPGridButton
impl CPGridButton
pub unsafe fn new() -> Retained<Self>
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourcepub unsafe fn initWithTitleVariants_image_handler(
this: Allocated<Self>,
title_variants: &NSArray<NSString>,
image: &UIImage,
handler: Option<&DynBlock<dyn Fn(NonNull<CPGridButton>)>>,
) -> Retained<Self>
Available on crate features block2 and objc2-ui-kit only.
pub unsafe fn initWithTitleVariants_image_handler( this: Allocated<Self>, title_variants: &NSArray<NSString>, image: &UIImage, handler: Option<&DynBlock<dyn Fn(NonNull<CPGridButton>)>>, ) -> Retained<Self>
block2 and objc2-ui-kit only.Initialize a button with a title and image.
Parameter titleVariants: An array of title variants for this button, arranged from most to least preferred. You must provide at least one title.
Parameter image: The image displayed on the button. It must be non-nil for the button to be displayed.
Parameter handler: A block to execute when the user selects the button. The block has no return value and takes the selected button as its only parameter.
The image must be non-nil and the title must be a non-zero length string for the button to be displayed.
To properly size your images, your app should size them to the display scale of the car screen. See -[CPInterfaceController carTraitCollection].
Sourcepub unsafe fn initWithTitleVariants_image_messageConfiguration_handler(
this: Allocated<Self>,
title_variants: &NSArray<NSString>,
image: &UIImage,
message_configuration: Option<&CPMessageGridItemConfiguration>,
handler: Option<&DynBlock<dyn Fn(NonNull<CPGridButton>)>>,
) -> Retained<Self>
Available on crate features block2 and objc2-ui-kit only.
pub unsafe fn initWithTitleVariants_image_messageConfiguration_handler( this: Allocated<Self>, title_variants: &NSArray<NSString>, image: &UIImage, message_configuration: Option<&CPMessageGridItemConfiguration>, handler: Option<&DynBlock<dyn Fn(NonNull<CPGridButton>)>>, ) -> Retained<Self>
block2 and objc2-ui-kit only.Initialize a button with a title, image, and message configuration.
Sourcepub unsafe fn isEnabled(&self) -> bool
pub unsafe fn isEnabled(&self) -> bool
A Boolean value indicating whether the button is enabled.
Set the value of this property to
YESto enable the button or
NOto disable it. The default value of this property is
YES.
Sourcepub unsafe fn setEnabled(&self, enabled: bool)
pub unsafe fn setEnabled(&self, enabled: bool)
Setter for isEnabled.
pub unsafe fn messageConfiguration( &self, ) -> Option<Retained<CPMessageGridItemConfiguration>>
Sourcepub unsafe fn image(&self) -> Retained<UIImage>
Available on crate feature objc2-ui-kit only.
pub unsafe fn image(&self) -> Retained<UIImage>
objc2-ui-kit only.The image displayed on the button.
Animated images are not supported. If an animated image is assigned, only the first image will be used. To properly size your list images, your app should size them to the display scale of the car screen. See -[CPInterfaceController carTraitCollection].
pub unsafe fn updateImage(&self, image: &UIImage)
objc2-ui-kit only.Sourcepub unsafe fn titleVariants(&self) -> Retained<NSArray<NSString>>
pub unsafe fn titleVariants(&self) -> Retained<NSArray<NSString>>
An array of title variants for this button, arranged from most to least preferred. The system will select a title from your list of provided variants that fits the available space. The variant strings should be provided as localized, displayable content.
pub unsafe fn updateTitleVariants(&self, title_variants: &NSArray<NSString>)
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for CPGridButton
impl AsRef<AnyObject> for CPGridButton
Sourceimpl AsRef<CPGridButton> for CPGridButton
impl AsRef<CPGridButton> for CPGridButton
Sourceimpl AsRef<NSObject> for CPGridButton
impl AsRef<NSObject> for CPGridButton
Sourceimpl Borrow<AnyObject> for CPGridButton
impl Borrow<AnyObject> for CPGridButton
Sourceimpl Borrow<NSObject> for CPGridButton
impl Borrow<NSObject> for CPGridButton
Sourceimpl ClassType for CPGridButton
impl ClassType for CPGridButton
Sourceconst NAME: &'static str = "CPGridButton"
const NAME: &'static str = "CPGridButton"
Sourcetype ThreadKind = <<CPGridButton as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<CPGridButton as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for CPGridButton
impl Debug for CPGridButton
Sourceimpl Deref for CPGridButton
impl Deref for CPGridButton
Sourceimpl Hash for CPGridButton
impl Hash for CPGridButton
Sourceimpl Message for CPGridButton
impl Message for CPGridButton
Sourceimpl NSCoding for CPGridButton
impl NSCoding for CPGridButton
Sourceimpl NSObjectProtocol for CPGridButton
impl NSObjectProtocol for CPGridButton
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref