pub struct CPInformationTemplate { /* private fields */ }CPInformationTemplate and CPTemplate only.Expand description
Implementations
Sourceimpl CPInformationTemplate
impl CPInformationTemplate
Sourcepub unsafe fn initWithTitle_layout_items_actions(
this: Allocated<Self>,
title: &NSString,
layout: CPInformationTemplateLayout,
items: &NSArray<CPInformationItem>,
actions: &NSArray<CPTextButton>,
) -> Retained<Self>
Available on crate features CPInformationItem and CPTextButton only.
pub unsafe fn initWithTitle_layout_items_actions( this: Allocated<Self>, title: &NSString, layout: CPInformationTemplateLayout, items: &NSArray<CPInformationItem>, actions: &NSArray<CPTextButton>, ) -> Retained<Self>
CPInformationItem and CPTextButton only.Initialize a CPInformationTemplate with a title, optional labels, and optional action buttons.
Parameter layout: Information template layout, either leading aligned or two columns
Parameter title: Information template title, appears at the top of the template
Parameter items: Information items that will appear in the template
Parameter actions: Optional actions that appear at the bottom of the template
Note: The maximum number of
CPInformationItemis 10. If you specify more than 10 items, only the first 10 will be used.
The maximum number of
CPTextButtonis 3. If you specify more than 3, only the first 3 will be used.
Sourcepub unsafe fn layout(&self) -> CPInformationTemplateLayout
pub unsafe fn layout(&self) -> CPInformationTemplateLayout
Information template layout, either leading aligned or two columns.
Sourcepub unsafe fn title(&self) -> Retained<NSString>
pub unsafe fn title(&self) -> Retained<NSString>
Title that will appear at the top of the template.
Sourcepub unsafe fn items(&self) -> Retained<NSArray<CPInformationItem>>
Available on crate feature CPInformationItem only.
pub unsafe fn items(&self) -> Retained<NSArray<CPInformationItem>>
CPInformationItem only.An array of
CPInformationItem.To update the items appearing in this information template, assign a new array to this property.
Note: The maximum number of items is 10. If you specify more than 10 items, only the first 10 will be used.
Sourcepub unsafe fn setItems(&self, items: &NSArray<CPInformationItem>)
Available on crate feature CPInformationItem only.
pub unsafe fn setItems(&self, items: &NSArray<CPInformationItem>)
CPInformationItem only.Sourcepub unsafe fn actions(&self) -> Retained<NSArray<CPTextButton>>
Available on crate feature CPTextButton only.
pub unsafe fn actions(&self) -> Retained<NSArray<CPTextButton>>
CPTextButton only.An array of actions that appear at the bottom of the template.
To update the actions appearing in this information template, assign a new array to this property.
Note: The maximum number of actions is 3. If you specify more than 3, only the first 3 will be used.
Sourcepub unsafe fn setActions(&self, actions: &NSArray<CPTextButton>)
Available on crate feature CPTextButton only.
pub unsafe fn setActions(&self, actions: &NSArray<CPTextButton>)
CPTextButton only.pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
Methods from Deref<Target = CPTemplate>
Sourcepub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>
pub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>
Any custom data or an object associated with this template can be stored in this property.
Sourcepub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)
pub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)
Sourcepub unsafe fn tabTitle(&self) -> Option<Retained<NSString>>
pub unsafe fn tabTitle(&self) -> Option<Retained<NSString>>
When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the
tabTitlespecified in this template.
Note: If no
tabTitleis specified, the tab will inherit the template’s title, if any.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabTitle(&self, tab_title: Option<&NSString>)
pub unsafe fn setTabTitle(&self, tab_title: Option<&NSString>)
Sourcepub unsafe fn tabImage(&self) -> Option<Retained<UIImage>>
Available on crate feature objc2-ui-kit only.
pub unsafe fn tabImage(&self) -> Option<Retained<UIImage>>
objc2-ui-kit only.When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the image specified in this template. If a tabSystemItem is also specified, tabImage will take precedence.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabImage(&self, tab_image: Option<&UIImage>)
Available on crate feature objc2-ui-kit only.
pub unsafe fn setTabImage(&self, tab_image: Option<&UIImage>)
objc2-ui-kit only.Setter for tabImage.
Sourcepub unsafe fn tabSystemItem(&self) -> UITabBarSystemItem
Available on crate feature objc2-ui-kit only.
pub unsafe fn tabSystemItem(&self) -> UITabBarSystemItem
objc2-ui-kit only.When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the system image AND system title specified in this template.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabSystemItem(&self, tab_system_item: UITabBarSystemItem)
Available on crate feature objc2-ui-kit only.
pub unsafe fn setTabSystemItem(&self, tab_system_item: UITabBarSystemItem)
objc2-ui-kit only.Setter for tabSystemItem.
Sourcepub unsafe fn showsTabBadge(&self) -> bool
pub unsafe fn showsTabBadge(&self) -> bool
When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab may optionally
display a badge indicator.
Note: This defaults to NO. Specify YES to display a badge indicator on this tab.
Sourcepub unsafe fn setShowsTabBadge(&self, shows_tab_badge: bool)
pub unsafe fn setShowsTabBadge(&self, shows_tab_badge: bool)
Setter for showsTabBadge.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for CPInformationTemplate
impl AsRef<AnyObject> for CPInformationTemplate
Sourceimpl AsRef<CPTemplate> for CPInformationTemplate
impl AsRef<CPTemplate> for CPInformationTemplate
Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<NSObject> for CPInformationTemplate
impl AsRef<NSObject> for CPInformationTemplate
Sourceimpl Borrow<AnyObject> for CPInformationTemplate
impl Borrow<AnyObject> for CPInformationTemplate
Sourceimpl Borrow<CPTemplate> for CPInformationTemplate
impl Borrow<CPTemplate> for CPInformationTemplate
Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<NSObject> for CPInformationTemplate
impl Borrow<NSObject> for CPInformationTemplate
Sourceimpl CPBarButtonProviding for CPInformationTemplate
impl CPBarButtonProviding for CPInformationTemplate
CPBarButtonProviding and CPBarButton only.CPBarButtonProviding and CPBarButton only.leadingNavigationBarButtons.CPBarButtonProviding and CPBarButton only.CPBarButtonProviding and CPBarButton only.trailingNavigationBarButtons.Sourceunsafe fn backButton(&self) -> Option<Retained<CPBarButton>>
unsafe fn backButton(&self) -> Option<Retained<CPBarButton>>
CPBarButtonProviding and CPBarButton only.Sourceunsafe fn setBackButton(&self, back_button: Option<&CPBarButton>)
unsafe fn setBackButton(&self, back_button: Option<&CPBarButton>)
CPBarButtonProviding and CPBarButton only.backButton.Sourceimpl ClassType for CPInformationTemplate
impl ClassType for CPInformationTemplate
Sourceconst NAME: &'static str = "CPInformationTemplate"
const NAME: &'static str = "CPInformationTemplate"
Sourcetype Super = CPTemplate
type Super = CPTemplate
Sourcetype ThreadKind = dyn MainThreadOnly
type ThreadKind = dyn MainThreadOnly
Sourceimpl Debug for CPInformationTemplate
impl Debug for CPInformationTemplate
Sourceimpl Deref for CPInformationTemplate
impl Deref for CPInformationTemplate
Sourceimpl Hash for CPInformationTemplate
impl Hash for CPInformationTemplate
Sourceimpl Message for CPInformationTemplate
impl Message for CPInformationTemplate
Sourceimpl NSCoding for CPInformationTemplate
impl NSCoding for CPInformationTemplate
Sourceimpl NSObjectProtocol for CPInformationTemplate
impl NSObjectProtocol for CPInformationTemplate
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl PartialEq for CPInformationTemplate
impl PartialEq for CPInformationTemplate
Sourceimpl RefEncode for CPInformationTemplate
impl RefEncode for CPInformationTemplate
Sourceconst ENCODING_REF: Encoding = <CPTemplate as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <CPTemplate as ::objc2::RefEncode>::ENCODING_REF
impl DowncastTarget for CPInformationTemplate
impl Eq for CPInformationTemplate