CPInstrumentClusterController

Struct CPInstrumentClusterController 

pub struct CPInstrumentClusterController { /* private fields */ }
Available on crate feature CPInstrumentClusterController only.
Implementations

Source

impl CPInstrumentClusterController

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn new() -> Retained<Self>

pub unsafe fn delegate( &self, ) -> Option<Retained<ProtocolObject<dyn CPInstrumentClusterControllerDelegate>>>

pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn CPInstrumentClusterControllerDelegate>>, )

Setter for delegate.

This is a weak property.

pub unsafe fn instrumentClusterWindow( &self, mtm: MainThreadMarker, ) -> Option<Retained<UIWindow>>

Available on crate feature objc2-ui-kit only.

The UIWindow created for this CPInstrumentClusterController

pub unsafe fn speedLimitSetting(&self) -> CPInstrumentClusterSetting

pub unsafe fn compassSetting(&self) -> CPInstrumentClusterSetting

pub unsafe fn inactiveDescriptionVariants(&self) -> Retained<NSArray<NSString>>

inactiveDescriptionVariants is an array of NSStringto be displayed when the user is not actively navigating, arranged from most to least preferred.

pub unsafe fn setInactiveDescriptionVariants( &self, inactive_description_variants: &NSArray<NSString>, )

Setter for inactiveDescriptionVariants.

This is copied when set.

pub unsafe fn attributedInactiveDescriptionVariants( &self, ) -> Retained<NSArray<NSAttributedString>>

attributedInactiveDescriptionVariants is an array of NSAttributedStringto be displayed when the user is not actively navigating, arranged from most to least preferred.

attributedInactiveDescriptionVariantswill be preferred over inactiveDescriptionVariants.

Only one type of attribute is presently supported: text attachments. You may annotate the string with images by including one or more text attachments. The maximum text attachment image size is 64x25 points.

Warning: All attributes other than text attachment attributes will be removed from your attributed string.

See: +[NSAttributedString attributedStringWithAttachment:], -[NSTextAttachment image]

pub unsafe fn setAttributedInactiveDescriptionVariants( &self, attributed_inactive_description_variants: &NSArray<NSAttributedString>, )

Setter for attributedInactiveDescriptionVariants.

This is copied when set.

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}