pub struct CPLane { /* private fields */ }CPLane only.Expand description
CPLanerepresents information about a single lane.
See also Apple’s documentation
Implementations
Sourceimpl CPLane
impl CPLane
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn initWithAngles( this: Allocated<Self>, angles: &NSArray<NSMeasurement<NSUnitAngle>>, ) -> Retained<Self>
pub unsafe fn initWithAngles_highlightedAngle_isPreferred( this: Allocated<Self>, angles: &NSArray<NSMeasurement<NSUnitAngle>>, highlighted_angle: &NSMeasurement<NSUnitAngle>, preferred: bool, ) -> Retained<Self>
Sourcepub unsafe fn status(&self) -> CPLaneStatus
pub unsafe fn status(&self) -> CPLaneStatus
status is a
CPLaneStatusrepresenting the status of this lane.
Sourcepub unsafe fn setStatus(&self, status: CPLaneStatus)
pub unsafe fn setStatus(&self, status: CPLaneStatus)
Setter for status.
Sourcepub unsafe fn primaryAngle(&self) -> Retained<NSMeasurement<NSUnitAngle>>
👎Deprecated: Use highlightedAngle to get value, use -[CPLane initAngles:highlightedAngle:isPreferred:] to create a CPLane with highlightedAngle set
pub unsafe fn primaryAngle(&self) -> Retained<NSMeasurement<NSUnitAngle>>
primaryAngle is the angle to be highlighted if this lane is preferred or good. If primaryAngle is present it can not be included in secondaryAngles.
Sourcepub unsafe fn setPrimaryAngle(&self, primary_angle: &NSMeasurement<NSUnitAngle>)
👎Deprecated: Use highlightedAngle to get value, use -[CPLane initAngles:highlightedAngle:isPreferred:] to create a CPLane with highlightedAngle set
pub unsafe fn setPrimaryAngle(&self, primary_angle: &NSMeasurement<NSUnitAngle>)
Setter for primaryAngle.
Sourcepub unsafe fn highlightedAngle(
&self,
) -> Option<Retained<NSMeasurement<NSUnitAngle>>>
pub unsafe fn highlightedAngle( &self, ) -> Option<Retained<NSMeasurement<NSUnitAngle>>>
highlightedAngleis the angle to be highlighted. If
highlightedAngleis present it can not be included in
angles.``highlightedAnglemust not be set if status is
CPLaneStatusNotGood
Sourcepub unsafe fn secondaryAngles(
&self,
) -> Retained<NSArray<NSMeasurement<NSUnitAngle>>>
👎Deprecated: Use angles to get value, Use -[CPLane initWithAngles:] or -[CPLane initAngles:highlightedAngle:isPreferred:] to create a CPLane with angles
pub unsafe fn secondaryAngles( &self, ) -> Retained<NSArray<NSMeasurement<NSUnitAngle>>>
secondaryAngles is a list of the remaining angles of this lane guidance.
Sourcepub unsafe fn setSecondaryAngles(
&self,
secondary_angles: &NSArray<NSMeasurement<NSUnitAngle>>,
)
👎Deprecated: Use angles to get value, Use -[CPLane initWithAngles:] or -[CPLane initAngles:highlightedAngle:isPreferred:] to create a CPLane with angles
pub unsafe fn setSecondaryAngles( &self, secondary_angles: &NSArray<NSMeasurement<NSUnitAngle>>, )
Setter for secondaryAngles.
Sourcepub unsafe fn angles(&self) -> Retained<NSArray<NSMeasurement<NSUnitAngle>>>
pub unsafe fn angles(&self) -> Retained<NSArray<NSMeasurement<NSUnitAngle>>>
anglesis a list of the remaining angles of this lane guidance. If
highlightedAngleis set, that angle must not be included in
angles
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl ClassType for CPLane
impl ClassType for CPLane
Sourceconst NAME: &'static str = "CPLane"
const NAME: &'static str = "CPLane"
Sourcetype ThreadKind = <<CPLane as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<CPLane as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl CopyingHelper for CPLane
impl CopyingHelper for CPLane
Sourceimpl NSCopying for CPLane
impl NSCopying for CPLane
Sourceimpl NSObjectProtocol for CPLane
impl NSObjectProtocol for CPLane
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref