CPListImageRowItem

Struct CPListImageRowItem 

pub struct CPListImageRowItem { /* private fields */ }
Available on crate feature CPListImageRowItem only.
Implementations

Source

impl CPListImageRowItem

pub unsafe fn initWithText_images( this: Allocated<Self>, text: &NSString, images: &NSArray<UIImage>, ) -> Retained<Self>

👎Deprecated: Use initWithText:elements:allowsMultipleLines:
Available on crate feature objc2-ui-kit only.

Initialize a list image row item with a text string and an array of UIImagefor the grid of images.

When providing an image, your app should provide a UIImagethat is display-ready. If necessary for the image, provide light and dark styles by using an asset from your asset catalog, prepared with light and dark styles or by using UIImageAssetto combine two UIImageinstances into a single image with both styles.

UIImageAsset is used to combine multiple UIImages with different trait collections into a single UIImage.

Note: The expected image size is given by +[CPListImageRowItem maximumImageSize]. Images provided will be resized to this size if necessary.

To properly size your images, your app should size them to the display scale of the car screen. See -[CPInterfaceController carTraitCollection].

pub unsafe fn initWithText_images_imageTitles( this: Allocated<Self>, text: &NSString, images: &NSArray<UIImage>, image_titles: &NSArray<NSString>, ) -> Retained<Self>

👎Deprecated: Use initWithText:elements:allowsMultipleLines:
Available on crate feature objc2-ui-kit only.

Initialize a list image row item with a text string, an array of UIImagefor the grid of images, and an array of NSStringtitles, one displayed below each image.

The number of titles in the imageTitleslist should be equal to the number of images in the imageslist.

When providing an image, your app should provide a UIImagethat is display-ready. If necessary for the image, provide light and dark styles by using an asset from your asset catalog, prepared with light and dark styles or by using UIImageAssetto combine two UIImageinstances into a single image with both styles.

UIImageAsset is used to combine multiple UIImages with different trait collections into a single UIImage.

Note: The expected image size is given by +[CPListImageRowItem maximumImageSize]. Images provided will be resized to this size if necessary.

To properly size your images, your app should size them to the display scale of the car screen. See -[CPInterfaceController carTraitCollection].

pub unsafe fn initWithText_elements_allowsMultipleLines( this: Allocated<Self>, text: Option<&NSString>, elements: &NSArray<CPListImageRowItemRowElement>, allows_multiple_lines: bool, ) -> Retained<Self>

Available on crate features CPListImageRowItemElement and CPListImageRowItemRowElement only.

Initialize a list image row item with a text string, an array of CPListImageRowItemRowElementand a boolean to allow multiple lines in this row.

If a nil textproperty is provided the cell will resize accordingly to hide the title.

Parameter text: The text visible at the top of the cell.

Parameter elements: The list of CPListImageRowItemRowElementelements visible below the text.

Parameter allowsMultipleLines: Determines if the elements could be visible on more than a single line.

pub unsafe fn initWithText_cardElements_allowsMultipleLines( this: Allocated<Self>, text: Option<&NSString>, elements: &NSArray<CPListImageRowItemCardElement>, allows_multiple_lines: bool, ) -> Retained<Self>

Available on crate features CPListImageRowItemCardElement and CPListImageRowItemElement only.

Initialize a list image row item with a text string, an array of CPListImageRowItemCardElementand a boolean to allow multiple lines in this row.

If a nil textproperty is provided the cell will resize accordingly to hide the title.

Parameter text: The text visible at the top of the cell.

Parameter cardElements: The list of CPListImageRowItemCardElementelements visible below the text.

Parameter allowsMultipleLines: Determines if the elements could be visible on more than a single line.

pub unsafe fn initWithText_condensedElements_allowsMultipleLines( this: Allocated<Self>, text: Option<&NSString>, elements: &NSArray<CPListImageRowItemCondensedElement>, allows_multiple_lines: bool, ) -> Retained<Self>

Available on crate features CPListImageRowItemCondensedElement and CPListImageRowItemElement only.

Initialize a list image row item with a text string, an array of CPListImageRowItemCondensedElementand a boolean to allow multiple lines in this row.

If a nil textproperty is provided the cell will resize accordingly to hide the title.

Parameter text: The text visible at the top of the cell.

Parameter condensedElements: The list of CPListImageRowItemCondensedElementelements visible below the text.

Parameter allowsMultipleLines: Determines if the elements could be visible on more than a single line.

pub unsafe fn initWithText_gridElements_allowsMultipleLines( this: Allocated<Self>, text: Option<&NSString>, elements: &NSArray<CPListImageRowItemGridElement>, allows_multiple_lines: bool, ) -> Retained<Self>

Available on crate features CPListImageRowItemElement and CPListImageRowItemGridElement only.

Initialize a list image row item with a text string, an array of CPListImageRowItemGridElementand a boolean to allow multiple lines in this row.

If a nil textproperty is provided the cell will resize accordingly to hide the title.

Parameter text: The text visible at the top of the cell.

Parameter gridElements: The list of CPListImageRowItemGridElementelements visible below the text.

Parameter allowsMultipleLines: Determines if the elements could be visible on more than a single line.

pub unsafe fn initWithText_imageGridElements_allowsMultipleLines( this: Allocated<Self>, text: Option<&NSString>, elements: &NSArray<CPListImageRowItemImageGridElement>, allows_multiple_lines: bool, ) -> Retained<Self>

Available on crate features CPListImageRowItemElement and CPListImageRowItemImageGridElement only.

Initialize a list image row item with a text string, an array of CPListImageRowItemImageGridElementand a boolean to allow multiple lines in this row.

If a nil textproperty is provided the cell will resize accordingly to hide the title.

Parameter text: The text visible at the top of the cell.

Parameter imageGridElements: The list of CPListImageRowItemImageGridElementelements visible below the text.

Parameter allowsMultipleLines: Determines if the elements could be visible on more than a single line.

pub unsafe fn text(&self) -> Option<Retained<NSString>>

The primary text shown in a cell displaying this list item.

pub unsafe fn setText(&self, text: Option<&NSString>)

Setter for text.

This is copied when set.

pub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>

Any custom user info related to this item.

pub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)

Setter for userInfo.

Safety

user_info should be of the correct type.

pub unsafe fn handler( &self, ) -> *mut DynBlock<dyn Fn(NonNull<ProtocolObject<dyn CPSelectableListItem>>, dispatch_block_t)>

Available on crate features CPListItemTypes and block2 and dispatch2 only.

An optional action block, fired when the user selects this item in a list template.

Safety
  • The returned block’s argument 1 must be a valid pointer.
  • The returned block’s argument 2 must be a valid pointer.
pub unsafe fn setHandler( &self, handler: Option<&DynBlock<dyn Fn(NonNull<ProtocolObject<dyn CPSelectableListItem>>, dispatch_block_t)>>, )

Available on crate features CPListItemTypes and block2 and dispatch2 only.

Setter for handler.

This is copied when set.

pub unsafe fn isEnabled(&self) -> bool

A Boolean value indicating whether the list item is enabled.

Set the value of this property to YESto enable the list item or NOto disable it. The default value of this property is YES.

pub unsafe fn setEnabled(&self, enabled: bool)

Setter for isEnabled.

pub unsafe fn gridImages(&self) -> Retained<NSArray<UIImage>>

👎Deprecated: No longer supported
Available on crate feature objc2-ui-kit only.

Read-only access to the grid images shown in a row in the cell.

Note: The maximum number of images shown is CPMaximumNumberOfGridImages.If you supply more images, only the first CPMaximumNumberOfGridImageswill be used.

pub unsafe fn updateImages(&self, grid_images: &NSArray<UIImage>)

👎Deprecated: No longer supported
Available on crate feature objc2-ui-kit only.

Update the images displayed in this image row item. If this image row item is already displayed in a list template, this image row item will be automatically reloaded.

When providing an image, your app should provide a UIImagethat is display-ready. If necessary for the image, provide light and dark styles by using an asset from your asset catalog, prepared with light and dark styles or by using UIImageAssetto combine two UIImageinstances into a single image with both styles.

UIImageAsset is used to combine multiple UIImages with different trait collections into a single UIImage.

See: To update/reload the title of the image row item, assign to the textproperty of the image row item.

See: To update/reload the title labels displayed below each image, assign to the imageTitlesproperty of the image row item.

pub unsafe fn imageTitles(&self) -> Retained<NSArray<NSString>>

👎Deprecated: No longer supported

The titles displayed for each image in this image row item.

See: To update/reload the title of the image row item, assign to the textproperty of the image row item.

pub unsafe fn elements(&self) -> Retained<NSArray<CPListImageRowItemElement>>

Available on crate feature CPListImageRowItemElement only.

The array of elements used to draw visible elements.

pub unsafe fn setElements(&self, elements: &NSArray<CPListImageRowItemElement>)

Available on crate feature CPListImageRowItemElement only.

Setter for elements.

This is copied when set.

pub unsafe fn allowsMultipleLines(&self) -> bool

A Boolean value indicating whether the elements should be visible in more than a single line.

Set the value of this property to YESto allow elements to be visible on multiple lines. Set the value of this property to NOto only show a single line of elements.

pub unsafe fn listImageRowHandler( &self, ) -> *mut DynBlock<dyn Fn(NonNull<CPListImageRowItem>, NSInteger, dispatch_block_t)>

Available on crate features block2 and dispatch2 only.

A block that is called when the user selects one of the images in this image row item.

The user may also select the cell itself - for that event, specify a handler.

Safety
  • The returned block’s argument 1 must be a valid pointer.
  • The returned block’s argument 3 must be a valid pointer.
pub unsafe fn setListImageRowHandler( &self, list_image_row_handler: Option<&DynBlock<dyn Fn(NonNull<CPListImageRowItem>, NSInteger, dispatch_block_t)>>, )

Available on crate features block2 and dispatch2 only.

Setter for listImageRowHandler.

This is copied when set.

pub unsafe fn maximumImageSize(mtm: MainThreadMarker) -> CGSize

👎Deprecated: Use +[CPListImageRowItemElement maximumImageSize] on an appropriate element
Available on crate feature objc2-core-foundation only.

The expected image size for the grid images in your CPListImageRowItem.Images provided will be resized to this size.

To properly size your images, your app should size them to the display scale of the car screen. See -[CPInterfaceController carTraitCollection].

Source

impl CPListImageRowItem

Methods declared on superclass NSObject.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}