pub struct CPListImageRowItemImageGridElement { /* private fields */ }CPListImageRowItemElement and CPListImageRowItemImageGridElement only.Expand description
Implementations
Sourceimpl CPListImageRowItemImageGridElement
impl CPListImageRowItemImageGridElement
Sourcepub unsafe fn initWithImage_imageShape_title_accessorySymbolName(
this: Allocated<Self>,
image: &UIImage,
image_shape: CPListImageRowItemImageGridElementShape,
title: &NSString,
accessory_symbol_name: Option<&NSString>,
) -> Retained<Self>
Available on crate feature objc2-ui-kit only.
pub unsafe fn initWithImage_imageShape_title_accessorySymbolName( this: Allocated<Self>, image: &UIImage, image_shape: CPListImageRowItemImageGridElementShape, title: &NSString, accessory_symbol_name: Option<&NSString>, ) -> Retained<Self>
objc2-ui-kit only.Initialize an element that is constituted of an image and an image shape.
When providing an image, your app should provide a
UIImagethat is display-ready. If necessary for the image, provide
light and dark styles by using an asset from your asset catalog, prepared with light and dark styles
or by using
UIImageAssetto combine two
UIImageinstances into a single image with
both styles.
UIImageAsset is used to combine multiple UIImages with different trait collections into a single UIImage.
Note: The expected image size is given by +[CPListImageRowItemImageGridElement maximumImageSize]. Images provided will be resized to this size if necessary.
To properly size your images, your app should size them to the display scale of the car screen. See -[CPInterfaceController carTraitCollection].
Parameter image: The image associated to the element.
Parameter imageShape: The
CPListImageRowItemImageGridElementShapeshape being applied on the image.
Parameter title: The title of the element.
Parameter accessorySymbolName: The system symbol used as an accessory view.
Sourcepub unsafe fn accessorySymbolName(&self) -> Option<Retained<NSString>>
pub unsafe fn accessorySymbolName(&self) -> Option<Retained<NSString>>
The name of the system symbol image to use as accessory.
Sourcepub unsafe fn setAccessorySymbolName(
&self,
accessory_symbol_name: Option<&NSString>,
)
pub unsafe fn setAccessorySymbolName( &self, accessory_symbol_name: Option<&NSString>, )
Setter for accessorySymbolName.
This is copied when set.
Sourcepub unsafe fn imageShape(&self) -> CPListImageRowItemImageGridElementShape
pub unsafe fn imageShape(&self) -> CPListImageRowItemImageGridElementShape
Shape used to draw the image of the element.
Sourceimpl CPListImageRowItemImageGridElement
Methods declared on superclass CPListImageRowItemElement.
impl CPListImageRowItemImageGridElement
Methods declared on superclass CPListImageRowItemElement.
Sourceimpl CPListImageRowItemImageGridElement
Methods declared on superclass NSObject.
impl CPListImageRowItemImageGridElement
Methods declared on superclass NSObject.
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
Methods from Deref<Target = CPListImageRowItemElement>
Sourcepub unsafe fn image(&self) -> Retained<UIImage>
Available on crate feature objc2-ui-kit only.
pub unsafe fn image(&self) -> Retained<UIImage>
objc2-ui-kit only.The image associated with this element.
Sourcepub unsafe fn isEnabled(&self) -> bool
pub unsafe fn isEnabled(&self) -> bool
A Boolean value indicating whether the list element is enabled.
Set the value of this property to
YESto enable the list element or
NOto disable it. The default value of this property is
YES.
Sourcepub unsafe fn setEnabled(&self, enabled: bool)
pub unsafe fn setEnabled(&self, enabled: bool)
Setter for isEnabled.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<CPListImageRowItemElement> for CPListImageRowItemImageGridElement
impl AsRef<CPListImageRowItemElement> for CPListImageRowItemImageGridElement
Sourcefn as_ref(&self) -> &CPListImageRowItemElement
fn as_ref(&self) -> &CPListImageRowItemElement
Sourceimpl Borrow<CPListImageRowItemElement> for CPListImageRowItemImageGridElement
impl Borrow<CPListImageRowItemElement> for CPListImageRowItemImageGridElement
Sourcefn borrow(&self) -> &CPListImageRowItemElement
fn borrow(&self) -> &CPListImageRowItemElement
Sourceimpl ClassType for CPListImageRowItemImageGridElement
impl ClassType for CPListImageRowItemImageGridElement
Sourceconst NAME: &'static str = "CPListImageRowItemImageGridElement"
const NAME: &'static str = "CPListImageRowItemImageGridElement"
Sourcetype Super = CPListImageRowItemElement
type Super = CPListImageRowItemElement
Sourcetype ThreadKind = dyn MainThreadOnly
type ThreadKind = dyn MainThreadOnly
Sourceimpl NSObjectProtocol for CPListImageRowItemImageGridElement
impl NSObjectProtocol for CPListImageRowItemImageGridElement
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl RefEncode for CPListImageRowItemImageGridElement
impl RefEncode for CPListImageRowItemImageGridElement
Sourceconst ENCODING_REF: Encoding = <CPListImageRowItemElement as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <CPListImageRowItemElement as ::objc2::RefEncode>::ENCODING_REF
impl DowncastTarget for CPListImageRowItemImageGridElement
impl Eq for CPListImageRowItemImageGridElement