#[repr(transparent)]pub struct CPListImageRowItemImageGridElementShape(pub NSInteger);Available on crate feature
CPListImageRowItemImageGridElement only.Expand description
Types of shape used to draw a list item.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl CPListImageRowItemImageGridElementShape
impl CPListImageRowItemImageGridElementShape
Sourcepub const RoundedRectangle: Self
pub const RoundedRectangle: Self
The list item will render a condensed list of rounded rectangle elements.