pub struct CPListSection { /* private fields */ }CPListSection only.Expand description
CPListSectionmodels a single section of items appearing in a
CPListTemplate.
See also Apple’s documentation
Implementations
Sourceimpl CPListSection
impl CPListSection
pub unsafe fn initWithItems_header_sectionIndexTitle( this: Allocated<Self>, items: &NSArray<ProtocolObject<dyn CPListTemplateItem>>, header: Option<&NSString>, section_index_title: Option<&NSString>, ) -> Retained<Self>
CPListItemTypes only.Sourcepub unsafe fn initWithItems_header_headerSubtitle_headerImage_headerButton_sectionIndexTitle(
this: Allocated<Self>,
items: &NSArray<ProtocolObject<dyn CPListTemplateItem>>,
header: &NSString,
header_subtitle: Option<&NSString>,
header_image: Option<&UIImage>,
header_button: Option<&CPButton>,
section_index_title: Option<&NSString>,
) -> Retained<Self>
Available on crate features CPButton and CPListItemTypes and objc2-ui-kit only.
pub unsafe fn initWithItems_header_headerSubtitle_headerImage_headerButton_sectionIndexTitle( this: Allocated<Self>, items: &NSArray<ProtocolObject<dyn CPListTemplateItem>>, header: &NSString, header_subtitle: Option<&NSString>, header_image: Option<&UIImage>, header_button: Option<&CPButton>, section_index_title: Option<&NSString>, ) -> Retained<Self>
CPButton and CPListItemTypes and objc2-ui-kit only.Create a section with a list of items and an optional header containing labels, an image, and a button.
Note: The maximum size of the section header image is given by CPMaximumListSectionImageSize.
When providing an image, your app may provide a
UIImagethat is display-ready. If necessary for the image, provide
light and dark styles by using an asset from your asset catalog, prepared with light and dark styles
or by using
UIImageAssetto combine two
UIImageinstances into a single image with
both styles.
UIImageAsset is used to combine multiple UIImages with different trait collections into a single UIImage.
To properly size your header image, your app should consider the display scale of the car screen. See -[CPInterfaceController carTraitCollection].
pub unsafe fn initWithItems( this: Allocated<Self>, items: &NSArray<ProtocolObject<dyn CPListTemplateItem>>, ) -> Retained<Self>
CPListItemTypes only.pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new() -> Retained<Self>
Sourcepub unsafe fn header(&self) -> Option<Retained<NSString>>
pub unsafe fn header(&self) -> Option<Retained<NSString>>
Optional string to use for a simple header in this section.
Sourcepub unsafe fn headerSubtitle(&self) -> Option<Retained<NSString>>
pub unsafe fn headerSubtitle(&self) -> Option<Retained<NSString>>
Optional section header elements used by the enhanced header in this section.
pub unsafe fn headerImage(&self) -> Option<Retained<UIImage>>
objc2-ui-kit only.Sourcepub unsafe fn setHeaderImage(&self, header_image: Option<&UIImage>)
Available on crate feature objc2-ui-kit only.
pub unsafe fn setHeaderImage(&self, header_image: Option<&UIImage>)
objc2-ui-kit only.Setter for headerImage.
This is copied when set.
pub unsafe fn headerButton(&self) -> Option<Retained<CPButton>>
CPButton only.Sourcepub unsafe fn sectionIndexTitle(&self) -> Option<Retained<NSString>>
pub unsafe fn sectionIndexTitle(&self) -> Option<Retained<NSString>>
An optional section index title to use in a table displaying this section. The system will enforce a maximum length of 1 for each section index title - in other words, you must choose single-character section index titles.
Sourcepub unsafe fn items(
&self,
) -> Retained<NSArray<ProtocolObject<dyn CPListTemplateItem>>>
Available on crate feature CPListItemTypes only.
pub unsafe fn items( &self, ) -> Retained<NSArray<ProtocolObject<dyn CPListTemplateItem>>>
CPListItemTypes only.Items appearing in this section.
Sourcepub unsafe fn indexOfItem(
&self,
item: &ProtocolObject<dyn CPListTemplateItem>,
) -> NSUInteger
Available on crate feature CPListItemTypes only.
pub unsafe fn indexOfItem( &self, item: &ProtocolObject<dyn CPListTemplateItem>, ) -> NSUInteger
CPListItemTypes only.Search for an item in this section, returning its index
or
NSNotFoundif not found.
Sourcepub unsafe fn itemAtIndex(
&self,
index: NSUInteger,
) -> Retained<ProtocolObject<dyn CPListTemplateItem>>
Available on crate feature CPListItemTypes only.
pub unsafe fn itemAtIndex( &self, index: NSUInteger, ) -> Retained<ProtocolObject<dyn CPListTemplateItem>>
CPListItemTypes only.Convenience access to the item in this section at the specified index.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for CPListSection
impl AsRef<AnyObject> for CPListSection
Sourceimpl AsRef<CPListSection> for CPListSection
impl AsRef<CPListSection> for CPListSection
Sourceimpl AsRef<NSObject> for CPListSection
impl AsRef<NSObject> for CPListSection
Sourceimpl Borrow<AnyObject> for CPListSection
impl Borrow<AnyObject> for CPListSection
Sourceimpl Borrow<NSObject> for CPListSection
impl Borrow<NSObject> for CPListSection
Sourceimpl ClassType for CPListSection
impl ClassType for CPListSection
Sourceconst NAME: &'static str = "CPListSection"
const NAME: &'static str = "CPListSection"
Sourcetype ThreadKind = <<CPListSection as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<CPListSection as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for CPListSection
impl Debug for CPListSection
Sourceimpl Deref for CPListSection
impl Deref for CPListSection
Sourceimpl Hash for CPListSection
impl Hash for CPListSection
Sourceimpl Message for CPListSection
impl Message for CPListSection
Sourceimpl NSCoding for CPListSection
impl NSCoding for CPListSection
Sourceimpl NSObjectProtocol for CPListSection
impl NSObjectProtocol for CPListSection
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref