CPMessageListItem

Struct CPMessageListItem 

pub struct CPMessageListItem { /* private fields */ }
Available on crate feature CPMessageListItem only.
CPMessageListItemis a special variant of a list item for use in a CPListTemplate.Unlike CPListItem,your application will not receive a callback when the user selects a CPMessageListItemin your list template. Instead, Siri will be invoked using the parameters you specify in your message item and the user will continue a message compose, read, or reply flow through Siri.

There are two modes of operation for CPMessageListItem:To represent an existing conversation with one or more recipients, use the CPMessageListIteminitializer that accepts a conversation identifier. This identifier is not directly displayed to the user; rather, it should be a value meaningful to your app to identify the conversation.

To represent a contact or person entity, use the CPMessageListIteminitializer that accepts a full name and phone/email. When the user selects this item, Siri will perform a message compose flow.

See also Apple’s documentation

Implementations

Source

impl CPMessageListItem

pub unsafe fn initWithConversationIdentifier_text_leadingConfiguration_trailingConfiguration_detailText_trailingText( this: Allocated<Self>, conversation_identifier: &NSString, text: &NSString, leading_configuration: &CPMessageListItemLeadingConfiguration, trailing_configuration: Option<&CPMessageListItemTrailingConfiguration>, detail_text: Option<&NSString>, trailing_text: Option<&NSString>, ) -> Retained<Self>

Initialize a CPMessageListItemfor use in a CPListTemplate.

Parameter conversationIdentifier: A value meaningful to your app to identify this conversation. This identifier is not directly displayed to the user; rather, when the user selects this list item, SiriKit will pass this identifier back to your app for your own use.

Parameter text: This is the main text label displayed to the user as well as spoken by Siri when the user selects this list item.

Parameter leadingConfiguration: A set of configuration options for the leading side of the list item.

Parameter trailingConfiguration: A set of configuration options for the trailing side of the list item.

Parameter detailText: Any additional text displayed underneath the conversationName. Parameter trailingText: Any additional text displayed along the trailing side of the cell.

Note: The maximum image size is CPMaximumMessageItemImageSize. If you supply a larger image, it will be scaled down to this size.

pub unsafe fn initWithFullName_phoneOrEmailAddress_leadingConfiguration_trailingConfiguration_detailText_trailingText( this: Allocated<Self>, full_name: &NSString, phone_or_email_address: &NSString, leading_configuration: &CPMessageListItemLeadingConfiguration, trailing_configuration: Option<&CPMessageListItemTrailingConfiguration>, detail_text: Option<&NSString>, trailing_text: Option<&NSString>, ) -> Retained<Self>

Initialize a CPMessageListItemfor use in a CPListTemplate.

Parameter fullName: The full name of the contact entity represented by this list item. This text will be displayed as the main text label in the cell and will be spoken by Siri.

Parameter phoneOrEmailAddress: A phone or email address for this contact entity that can be used to compose a message.

Parameter leadingConfiguration: A set of configuration options for the leading side of the list item.

Parameter trailingConfiguration: A set of configuration options for the trailing side of the list item.

Parameter detailText: Any additional text displayed underneath the conversationName. Parameter trailingText: Any additional text displayed along the trailing side of the cell.

Note: The maximum image size is CPMaximumMessageItemImageSize. If you supply a larger image, it will be scaled down to this size.

pub unsafe fn text(&self) -> Option<Retained<NSString>>

To update the CPMessageListItem,assign to any of these properties. If displayed in a list template, the list item will be automatically reloaded.

pub unsafe fn setText(&self, text: Option<&NSString>)

Setter for text.

This is copied when set.

pub unsafe fn conversationIdentifier(&self) -> Option<Retained<NSString>>

pub unsafe fn setConversationIdentifier( &self, conversation_identifier: Option<&NSString>, )

Setter for conversationIdentifier.

This is copied when set.

pub unsafe fn phoneOrEmailAddress(&self) -> Option<Retained<NSString>>

pub unsafe fn setPhoneOrEmailAddress( &self, phone_or_email_address: Option<&NSString>, )

Setter for phoneOrEmailAddress.

This is copied when set.

pub unsafe fn leadingConfiguration( &self, ) -> Retained<CPMessageListItemLeadingConfiguration>

pub unsafe fn setLeadingConfiguration( &self, leading_configuration: &CPMessageListItemLeadingConfiguration, )

pub unsafe fn trailingConfiguration( &self, ) -> Option<Retained<CPMessageListItemTrailingConfiguration>>

pub unsafe fn setTrailingConfiguration( &self, trailing_configuration: Option<&CPMessageListItemTrailingConfiguration>, )

pub unsafe fn detailText(&self) -> Option<Retained<NSString>>

pub unsafe fn setDetailText(&self, detail_text: Option<&NSString>)

Setter for detailText.

This is copied when set.

pub unsafe fn trailingText(&self) -> Option<Retained<NSString>>

pub unsafe fn setTrailingText(&self, trailing_text: Option<&NSString>)

Setter for trailingText.

This is copied when set.

pub unsafe fn isEnabled(&self) -> bool

A Boolean value indicating whether the list item is enabled.

Set the value of this property to YESto enable the list item or NOto disable it. The default value of this property is YES.

pub unsafe fn setEnabled(&self, enabled: bool)

Setter for isEnabled.

pub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>

Any custom user info related to this item.

pub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)

Setter for userInfo.

Safety

user_info should be of the correct type.

pub unsafe fn leadingDetailTextImage(&self) -> Option<Retained<UIImage>>

Available on crate feature objc2-ui-kit only.

Image shown on the leading edge of the detail text.

pub unsafe fn setLeadingDetailTextImage( &self, leading_detail_text_image: Option<&UIImage>, )

Available on crate feature objc2-ui-kit only.

Setter for leadingDetailTextImage.

This is copied when set.

Source

impl CPMessageListItem

Methods declared on superclass NSObject.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}