CPNavigationAlert

Struct CPNavigationAlert 

pub struct CPNavigationAlert { /* private fields */ }
Available on crate feature CPNavigationAlert only.
CPNavigationAlertis a banner alert that can display map or navigation-related information to the user.

See also Apple’s documentation

Implementations

Source

impl CPNavigationAlert

pub unsafe fn initWithTitleVariants_subtitleVariants_imageSet_primaryAction_secondaryAction_duration( this: Allocated<Self>, title_variants: &NSArray<NSString>, subtitle_variants: Option<&NSArray<NSString>>, image_set: Option<&CPImageSet>, primary_action: &CPAlertAction, secondary_action: Option<&CPAlertAction>, duration: NSTimeInterval, ) -> Retained<Self>

👎Deprecated
Available on crate features CPAlertAction and CPImageSet only.

Fully specify a CPNavigationAlertwith a title, image, primary and secondary action, and duration.

Parameter titleVariants: An array of titles. The system will select a title that fits in the available space. The variant strings should be provided as localized, displayable content.

Parameter subtitleVariants: An array of subtitles. The system will select a subtitle that fits in the available space. The variant strings should be provided as localized, displayable content.

Parameter imageSet: An optional CPImageSetto display in this navigation alert. Animated images are not supported. If an animated image is provided, only the first image from each image set will be used.

Parameter primaryAction: The alert must include at least one action button.

Parameter secondaryAction: An optional secondary button to display on the trailing edge of this alert.

Parameter duration: The duration for which this alert should be visible. Specify 0 for an alert that displays indefinitely.

Returns: an initialized CPNavigationAlert.

pub unsafe fn initWithTitleVariants_subtitleVariants_image_primaryAction_secondaryAction_duration( this: Allocated<Self>, title_variants: &NSArray<NSString>, subtitle_variants: Option<&NSArray<NSString>>, image: Option<&UIImage>, primary_action: &CPAlertAction, secondary_action: Option<&CPAlertAction>, duration: NSTimeInterval, ) -> Retained<Self>

Available on crate features CPAlertAction and objc2-ui-kit only.
pub unsafe fn updateTitleVariants_subtitleVariants( &self, new_title_variants: &NSArray<NSString>, new_subtitle_variants: &NSArray<NSString>, )

The navigation alert may be updated with new title and subtitle variants, either after it has already been displayed on screen, or before its initial presentation on screen.

Updating an alert that has been already been dismissed has no effect.

Parameter newTitleVariants: an updated array of title variants

Parameter newSubtitleVariants: an updated array of subtitle variants

pub unsafe fn titleVariants(&self) -> Retained<NSArray<NSString>>

pub unsafe fn subtitleVariants(&self) -> Retained<NSArray<NSString>>

pub unsafe fn imageSet(&self) -> Option<Retained<CPImageSet>>

Available on crate feature CPImageSet only.
pub unsafe fn image(&self) -> Option<Retained<UIImage>>

Available on crate feature objc2-ui-kit only.
pub unsafe fn primaryAction(&self) -> Retained<CPAlertAction>

Available on crate feature CPAlertAction only.
pub unsafe fn secondaryAction(&self) -> Option<Retained<CPAlertAction>>

Available on crate feature CPAlertAction only.
pub unsafe fn duration(&self) -> NSTimeInterval

Source

impl CPNavigationAlert

Methods declared on superclass NSObject.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}