pub struct CPNowPlayingRepeatButton { /* private fields */ }CPNowPlayingButton only.Expand description
A now playing button that shows the current repeat state, like “once” or “all”.
See also Apple’s documentation
Implementations
Sourceimpl CPNowPlayingRepeatButton
Methods declared on superclass CPNowPlayingButton.
impl CPNowPlayingRepeatButton
Methods declared on superclass CPNowPlayingButton.
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourcepub unsafe fn initWithHandler(
this: Allocated<Self>,
handler: Option<&DynBlock<dyn Fn(NonNull<CPNowPlayingButton>)>>,
) -> Retained<Self>
Available on crate feature block2 only.
pub unsafe fn initWithHandler( this: Allocated<Self>, handler: Option<&DynBlock<dyn Fn(NonNull<CPNowPlayingButton>)>>, ) -> Retained<Self>
block2 only.Initialize a now playing button with a handler. The handler will be called when the user selects this button.
Note: Your app should use this method in one of the six concrete subclasses of
CPNowPlayingButton.Do not initialize this class directly.
Methods from Deref<Target = CPNowPlayingButton>
Sourcepub unsafe fn isEnabled(&self) -> bool
pub unsafe fn isEnabled(&self) -> bool
A Boolean value indicating whether the button is enabled.
Set the value of this property to
YESto enable the button or
NOto disable it. The default value of this property is
YES.
Sourcepub unsafe fn setEnabled(&self, enabled: bool)
pub unsafe fn setEnabled(&self, enabled: bool)
Setter for isEnabled.
Sourcepub unsafe fn isSelected(&self) -> bool
pub unsafe fn isSelected(&self) -> bool
A Boolean value indicating whether the button is selected. When selected, the button draws with a selected appearance to indicate its selected state.
Only custom image buttons may display a custom selected state. Other system-provided buttons, like repeat and shuffle, change their selected states depending on what your app reports for current repeat and shuffle states.
Sourcepub unsafe fn setSelected(&self, selected: bool)
pub unsafe fn setSelected(&self, selected: bool)
Setter for isSelected.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for CPNowPlayingRepeatButton
impl AsRef<AnyObject> for CPNowPlayingRepeatButton
Sourceimpl AsRef<CPNowPlayingButton> for CPNowPlayingRepeatButton
impl AsRef<CPNowPlayingButton> for CPNowPlayingRepeatButton
Sourcefn as_ref(&self) -> &CPNowPlayingButton
fn as_ref(&self) -> &CPNowPlayingButton
Sourceimpl AsRef<NSObject> for CPNowPlayingRepeatButton
impl AsRef<NSObject> for CPNowPlayingRepeatButton
Sourceimpl Borrow<AnyObject> for CPNowPlayingRepeatButton
impl Borrow<AnyObject> for CPNowPlayingRepeatButton
Sourceimpl Borrow<CPNowPlayingButton> for CPNowPlayingRepeatButton
impl Borrow<CPNowPlayingButton> for CPNowPlayingRepeatButton
Sourcefn borrow(&self) -> &CPNowPlayingButton
fn borrow(&self) -> &CPNowPlayingButton
Sourceimpl Borrow<NSObject> for CPNowPlayingRepeatButton
impl Borrow<NSObject> for CPNowPlayingRepeatButton
Sourceimpl ClassType for CPNowPlayingRepeatButton
impl ClassType for CPNowPlayingRepeatButton
Sourceconst NAME: &'static str = "CPNowPlayingRepeatButton"
const NAME: &'static str = "CPNowPlayingRepeatButton"
Sourcetype Super = CPNowPlayingButton
type Super = CPNowPlayingButton
Sourcetype ThreadKind = dyn MainThreadOnly
type ThreadKind = dyn MainThreadOnly
Sourceimpl Debug for CPNowPlayingRepeatButton
impl Debug for CPNowPlayingRepeatButton
Sourceimpl Deref for CPNowPlayingRepeatButton
impl Deref for CPNowPlayingRepeatButton
Sourceimpl Hash for CPNowPlayingRepeatButton
impl Hash for CPNowPlayingRepeatButton
Sourceimpl Message for CPNowPlayingRepeatButton
impl Message for CPNowPlayingRepeatButton
Sourceimpl NSCoding for CPNowPlayingRepeatButton
impl NSCoding for CPNowPlayingRepeatButton
Sourceimpl NSObjectProtocol for CPNowPlayingRepeatButton
impl NSObjectProtocol for CPNowPlayingRepeatButton
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl PartialEq for CPNowPlayingRepeatButton
impl PartialEq for CPNowPlayingRepeatButton
Sourceimpl RefEncode for CPNowPlayingRepeatButton
impl RefEncode for CPNowPlayingRepeatButton
Sourceconst ENCODING_REF: Encoding = <CPNowPlayingButton as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <CPNowPlayingButton as ::objc2::RefEncode>::ENCODING_REF
impl DowncastTarget for CPNowPlayingRepeatButton
impl Eq for CPNowPlayingRepeatButton