pub struct CPNowPlayingSportsEventStatus { /* private fields */ }CPNowPlayingMode only.Expand description
A representation of the status of a sporting event.
See also Apple’s documentation
Implementations
Sourceimpl CPNowPlayingSportsEventStatus
impl CPNowPlayingSportsEventStatus
Sourcepub unsafe fn initWithEventStatusText_eventStatusImage_eventClock(
this: Allocated<Self>,
event_status_text: Option<&NSArray<NSString>>,
event_status_image: Option<&UIImage>,
event_clock: Option<&CPNowPlayingSportsClock>,
) -> Retained<Self>
Available on crate feature objc2-ui-kit only.
pub unsafe fn initWithEventStatusText_eventStatusImage_eventClock( this: Allocated<Self>, event_status_text: Option<&NSArray<NSString>>, event_status_image: Option<&UIImage>, event_clock: Option<&CPNowPlayingSportsClock>, ) -> Retained<Self>
objc2-ui-kit only.Initialize an event status with optional event status text, an optional event status image, and an optional event clock.
Parameter eventStatusText: Up to three separate strings for event status may be displayed.
The first string should always be used to show the play period (quarter, inning, period) using as few characters as possible; e.g. “2nd” for the 2nd quarter.
The second and third strings can be used to display additional information, like “1st & 10” and “SF 15” for an American football game.
All three strings should be kept as brief as possible to ensure they display well on car screens of various sizes.
Parameter eventStatusImage: An optional event status image for this event, if it applies to this event. For example,
a baseball game could display a representation of the bases and outs, indicating
how many bases are loaded and the number of outs in the current inning.
Parameter eventClock: The event timer, if it applies to this event. See
CPNowPlayingSportsClock.
Sourcepub unsafe fn eventStatusText(&self) -> Option<Retained<NSArray<NSString>>>
pub unsafe fn eventStatusText(&self) -> Option<Retained<NSArray<NSString>>>
Up to three separate strings for event status may be displayed.
The first string should always be used to show the play period (quarter, inning, period) using as few characters as possible; e.g. “2nd” for the 2nd quarter.
The second and third strings can be used to display additional information, like “1st & 10” and “SF 15” for an American football game.
All three strings should be kept as brief as possible to ensure they display well on car screens of various sizes.
Sourcepub unsafe fn eventClock(&self) -> Option<Retained<CPNowPlayingSportsClock>>
pub unsafe fn eventClock(&self) -> Option<Retained<CPNowPlayingSportsClock>>
The event timer, if it applies to this event. See
CPNowPlayingSportsClock.
Sourcepub unsafe fn eventStatusImage(&self) -> Option<Retained<UIImage>>
Available on crate feature objc2-ui-kit only.
pub unsafe fn eventStatusImage(&self) -> Option<Retained<UIImage>>
objc2-ui-kit only.An optional event status image for this event, if it applies to this event. For example, a baseball game could display a representation of the bases and outs, indicating how many bases are loaded and the number of outs in the current inning.
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl ClassType for CPNowPlayingSportsEventStatus
impl ClassType for CPNowPlayingSportsEventStatus
Sourceconst NAME: &'static str = "CPNowPlayingSportsEventStatus"
const NAME: &'static str = "CPNowPlayingSportsEventStatus"
Sourcetype ThreadKind = dyn MainThreadOnly
type ThreadKind = dyn MainThreadOnly
Sourceimpl Hash for CPNowPlayingSportsEventStatus
impl Hash for CPNowPlayingSportsEventStatus
Sourceimpl NSObjectProtocol for CPNowPlayingSportsEventStatus
impl NSObjectProtocol for CPNowPlayingSportsEventStatus
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl RefEncode for CPNowPlayingSportsEventStatus
impl RefEncode for CPNowPlayingSportsEventStatus
Sourceconst ENCODING_REF: Encoding = <NSObject as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <NSObject as ::objc2::RefEncode>::ENCODING_REF
impl DowncastTarget for CPNowPlayingSportsEventStatus
impl Eq for CPNowPlayingSportsEventStatus