pub struct CPNowPlayingTemplate { /* private fields */ }CPNowPlayingTemplate and CPTemplate only.Expand description
Implementations
Sourceimpl CPNowPlayingTemplate
impl CPNowPlayingTemplate
Access the shared now playing template for your app. Instead of creating your own now playing template, you should configure the properties of this shared instance.
You should present this shared instance when your app needs to present now playing, for example in response to the user selecting a playable item.
When the system needs to present now playing on behalf of your app, it will present this shared instance.
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
Sourcepub unsafe fn addObserver(
&self,
observer: &ProtocolObject<dyn CPNowPlayingTemplateObserver>,
)
pub unsafe fn addObserver( &self, observer: &ProtocolObject<dyn CPNowPlayingTemplateObserver>, )
Add an observer. Observers are notified about now playing template events.
Sourcepub unsafe fn removeObserver(
&self,
observer: &ProtocolObject<dyn CPNowPlayingTemplateObserver>,
)
pub unsafe fn removeObserver( &self, observer: &ProtocolObject<dyn CPNowPlayingTemplateObserver>, )
Remove an observer.
Sourcepub unsafe fn nowPlayingButtons(&self) -> Retained<NSArray<CPNowPlayingButton>>
Available on crate feature CPNowPlayingButton only.
pub unsafe fn nowPlayingButtons(&self) -> Retained<NSArray<CPNowPlayingButton>>
CPNowPlayingButton only.Playback control buttons on the Now Playing screen, like repeat, shuffle, and more.
Your application may specify a maximum of 5 now playing buttons.
Buttons are filled in array order, from the leading side to the trailing side of the screen.
Sourcepub unsafe fn isUpNextButtonEnabled(&self) -> bool
pub unsafe fn isUpNextButtonEnabled(&self) -> bool
A Boolean value indicating whether the “Up Next” button on the upper right of a Now Playing view is enabled.
Set the value of this property to
YESto enable the button.
Defaults to NO.
Sourcepub unsafe fn setUpNextButtonEnabled(&self, up_next_button_enabled: bool)
pub unsafe fn setUpNextButtonEnabled(&self, up_next_button_enabled: bool)
Setter for isUpNextButtonEnabled.
Sourcepub unsafe fn upNextTitle(&self) -> Retained<NSString>
pub unsafe fn upNextTitle(&self) -> Retained<NSString>
If your template elects to display the “Up Next” button, you may optionally specify a string indicating the title for the up next button. If no title is specified, a default system title will be used.
See: -[CPNowPlayingTemplate upNextButtonEnabled].
Sourcepub unsafe fn setUpNextTitle(&self, up_next_title: &NSString)
pub unsafe fn setUpNextTitle(&self, up_next_title: &NSString)
Setter for upNextTitle.
This is copied when set.
Sourcepub unsafe fn isAlbumArtistButtonEnabled(&self) -> bool
pub unsafe fn isAlbumArtistButtonEnabled(&self) -> bool
A Boolean value indicating whether the string that displays the album and artist above the playback controls should be a tappable button
Set the value of this property to
YESto enable the button.
Defaults to NO.
Sourcepub unsafe fn setAlbumArtistButtonEnabled(
&self,
album_artist_button_enabled: bool,
)
pub unsafe fn setAlbumArtistButtonEnabled( &self, album_artist_button_enabled: bool, )
Setter for isAlbumArtistButtonEnabled.
Sourcepub unsafe fn updateNowPlayingButtons(
&self,
now_playing_buttons: &NSArray<CPNowPlayingButton>,
)
Available on crate feature CPNowPlayingButton only.
pub unsafe fn updateNowPlayingButtons( &self, now_playing_buttons: &NSArray<CPNowPlayingButton>, )
CPNowPlayingButton only.Update the buttons displayed in this Now Playing template.
Sourcepub unsafe fn nowPlayingMode(&self) -> Option<Retained<CPNowPlayingMode>>
Available on crate feature CPNowPlayingMode only.
pub unsafe fn nowPlayingMode(&self) -> Option<Retained<CPNowPlayingMode>>
CPNowPlayingMode only.The currently-active now playing mode. See
CPNowPlayingMode.
Sourcepub unsafe fn setNowPlayingMode(
&self,
now_playing_mode: Option<&CPNowPlayingMode>,
)
Available on crate feature CPNowPlayingMode only.
pub unsafe fn setNowPlayingMode( &self, now_playing_mode: Option<&CPNowPlayingMode>, )
CPNowPlayingMode only.Setter for nowPlayingMode.
Methods from Deref<Target = CPTemplate>
Sourcepub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>
pub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>
Any custom data or an object associated with this template can be stored in this property.
Sourcepub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)
pub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)
Sourcepub unsafe fn tabTitle(&self) -> Option<Retained<NSString>>
pub unsafe fn tabTitle(&self) -> Option<Retained<NSString>>
When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the
tabTitlespecified in this template.
Note: If no
tabTitleis specified, the tab will inherit the template’s title, if any.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabTitle(&self, tab_title: Option<&NSString>)
pub unsafe fn setTabTitle(&self, tab_title: Option<&NSString>)
Sourcepub unsafe fn tabImage(&self) -> Option<Retained<UIImage>>
Available on crate feature objc2-ui-kit only.
pub unsafe fn tabImage(&self) -> Option<Retained<UIImage>>
objc2-ui-kit only.When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the image specified in this template. If a tabSystemItem is also specified, tabImage will take precedence.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabImage(&self, tab_image: Option<&UIImage>)
Available on crate feature objc2-ui-kit only.
pub unsafe fn setTabImage(&self, tab_image: Option<&UIImage>)
objc2-ui-kit only.Setter for tabImage.
Sourcepub unsafe fn tabSystemItem(&self) -> UITabBarSystemItem
Available on crate feature objc2-ui-kit only.
pub unsafe fn tabSystemItem(&self) -> UITabBarSystemItem
objc2-ui-kit only.When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the system image AND system title specified in this template.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabSystemItem(&self, tab_system_item: UITabBarSystemItem)
Available on crate feature objc2-ui-kit only.
pub unsafe fn setTabSystemItem(&self, tab_system_item: UITabBarSystemItem)
objc2-ui-kit only.Setter for tabSystemItem.
Sourcepub unsafe fn showsTabBadge(&self) -> bool
pub unsafe fn showsTabBadge(&self) -> bool
When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab may optionally
display a badge indicator.
Note: This defaults to NO. Specify YES to display a badge indicator on this tab.
Sourcepub unsafe fn setShowsTabBadge(&self, shows_tab_badge: bool)
pub unsafe fn setShowsTabBadge(&self, shows_tab_badge: bool)
Setter for showsTabBadge.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for CPNowPlayingTemplate
impl AsRef<AnyObject> for CPNowPlayingTemplate
Sourceimpl AsRef<CPTemplate> for CPNowPlayingTemplate
impl AsRef<CPTemplate> for CPNowPlayingTemplate
Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<NSObject> for CPNowPlayingTemplate
impl AsRef<NSObject> for CPNowPlayingTemplate
Sourceimpl Borrow<AnyObject> for CPNowPlayingTemplate
impl Borrow<AnyObject> for CPNowPlayingTemplate
Sourceimpl Borrow<CPTemplate> for CPNowPlayingTemplate
impl Borrow<CPTemplate> for CPNowPlayingTemplate
Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<NSObject> for CPNowPlayingTemplate
impl Borrow<NSObject> for CPNowPlayingTemplate
Sourceimpl ClassType for CPNowPlayingTemplate
impl ClassType for CPNowPlayingTemplate
Sourceconst NAME: &'static str = "CPNowPlayingTemplate"
const NAME: &'static str = "CPNowPlayingTemplate"
Sourcetype Super = CPTemplate
type Super = CPTemplate
Sourcetype ThreadKind = dyn MainThreadOnly
type ThreadKind = dyn MainThreadOnly
Sourceimpl Debug for CPNowPlayingTemplate
impl Debug for CPNowPlayingTemplate
Sourceimpl Deref for CPNowPlayingTemplate
impl Deref for CPNowPlayingTemplate
Sourceimpl Hash for CPNowPlayingTemplate
impl Hash for CPNowPlayingTemplate
Sourceimpl Message for CPNowPlayingTemplate
impl Message for CPNowPlayingTemplate
Sourceimpl NSCoding for CPNowPlayingTemplate
impl NSCoding for CPNowPlayingTemplate
Sourceimpl NSObjectProtocol for CPNowPlayingTemplate
impl NSObjectProtocol for CPNowPlayingTemplate
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl PartialEq for CPNowPlayingTemplate
impl PartialEq for CPNowPlayingTemplate
Sourceimpl RefEncode for CPNowPlayingTemplate
impl RefEncode for CPNowPlayingTemplate
Sourceconst ENCODING_REF: Encoding = <CPTemplate as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <CPTemplate as ::objc2::RefEncode>::ENCODING_REF
impl DowncastTarget for CPNowPlayingTemplate
impl Eq for CPNowPlayingTemplate