pub struct CPPointOfInterestTemplate { /* private fields */ }CPPointOfInterestTemplate and CPTemplate only.Expand description
Implementations
Sourceimpl CPPointOfInterestTemplate
impl CPPointOfInterestTemplate
Sourcepub unsafe fn initWithTitle_pointsOfInterest_selectedIndex(
this: Allocated<Self>,
title: &NSString,
points_of_interest: &NSArray<CPPointOfInterest>,
selected_index: NSUInteger,
) -> Retained<Self>
Available on crate feature CPPointOfInterest only.
pub unsafe fn initWithTitle_pointsOfInterest_selectedIndex( this: Allocated<Self>, title: &NSString, points_of_interest: &NSArray<CPPointOfInterest>, selected_index: NSUInteger, ) -> Retained<Self>
CPPointOfInterest only.CPPointOfInterestTemplate displays a map view with selectable points of interest.
Parameter title: Template title
Parameter pointsOfInterest: Points of interest to be presented in the map.
Parameter selectedIndex: Index of selected point of interest instance referenced in the pointsOfInterest array. Use NSNotFound to indicate no selection.
Note: the maximum number of POIs is 12. If you provide more than 12, only the first 12 will be used.
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
Sourcepub unsafe fn title(&self) -> Retained<NSString>
pub unsafe fn title(&self) -> Retained<NSString>
Template title appears on the template point of interest picker
Sourcepub unsafe fn setPointsOfInterest_selectedIndex(
&self,
points_of_interest: &NSArray<CPPointOfInterest>,
selected_index: NSUInteger,
)
Available on crate feature CPPointOfInterest only.
pub unsafe fn setPointsOfInterest_selectedIndex( &self, points_of_interest: &NSArray<CPPointOfInterest>, selected_index: NSUInteger, )
CPPointOfInterest only.Update the template with a list of points of interests to dispay
Parameter pointsOfInterest: Points of interest to be presented in the map.
Parameter selectedIndex: Index of selected point of interest instance referenced in the pointsOfInterest array. Use NSNotFound to indicate no selection.
Note: the maximum number of POIs is 12. If you provide more than 12, only the first 12 will be used.
pub unsafe fn pointsOfInterest(&self) -> Retained<NSArray<CPPointOfInterest>>
CPPointOfInterest only.Sourcepub unsafe fn selectedIndex(&self) -> NSUInteger
pub unsafe fn selectedIndex(&self) -> NSUInteger
Designate an instance in the pointsOfInterest array to highlight. Use NSNotFound to indicate no selection.
Sourcepub unsafe fn setSelectedIndex(&self, selected_index: NSUInteger)
pub unsafe fn setSelectedIndex(&self, selected_index: NSUInteger)
Setter for selectedIndex.
Sourcepub unsafe fn pointOfInterestDelegate(
&self,
) -> Option<Retained<ProtocolObject<dyn CPPointOfInterestTemplateDelegate>>>
pub unsafe fn pointOfInterestDelegate( &self, ) -> Option<Retained<ProtocolObject<dyn CPPointOfInterestTemplateDelegate>>>
The Point of Interest template’s delegate is informed of user events.
Sourcepub unsafe fn setPointOfInterestDelegate(
&self,
point_of_interest_delegate: Option<&ProtocolObject<dyn CPPointOfInterestTemplateDelegate>>,
)
pub unsafe fn setPointOfInterestDelegate( &self, point_of_interest_delegate: Option<&ProtocolObject<dyn CPPointOfInterestTemplateDelegate>>, )
Setter for pointOfInterestDelegate.
This is a weak property.
Methods from Deref<Target = CPTemplate>
Sourcepub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>
pub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>
Any custom data or an object associated with this template can be stored in this property.
Sourcepub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)
pub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)
Sourcepub unsafe fn tabTitle(&self) -> Option<Retained<NSString>>
pub unsafe fn tabTitle(&self) -> Option<Retained<NSString>>
When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the
tabTitlespecified in this template.
Note: If no
tabTitleis specified, the tab will inherit the template’s title, if any.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabTitle(&self, tab_title: Option<&NSString>)
pub unsafe fn setTabTitle(&self, tab_title: Option<&NSString>)
Sourcepub unsafe fn tabImage(&self) -> Option<Retained<UIImage>>
Available on crate feature objc2-ui-kit only.
pub unsafe fn tabImage(&self) -> Option<Retained<UIImage>>
objc2-ui-kit only.When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the image specified in this template. If a tabSystemItem is also specified, tabImage will take precedence.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabImage(&self, tab_image: Option<&UIImage>)
Available on crate feature objc2-ui-kit only.
pub unsafe fn setTabImage(&self, tab_image: Option<&UIImage>)
objc2-ui-kit only.Setter for tabImage.
Sourcepub unsafe fn tabSystemItem(&self) -> UITabBarSystemItem
Available on crate feature objc2-ui-kit only.
pub unsafe fn tabSystemItem(&self) -> UITabBarSystemItem
objc2-ui-kit only.When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the system image AND system title specified in this template.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabSystemItem(&self, tab_system_item: UITabBarSystemItem)
Available on crate feature objc2-ui-kit only.
pub unsafe fn setTabSystemItem(&self, tab_system_item: UITabBarSystemItem)
objc2-ui-kit only.Setter for tabSystemItem.
Sourcepub unsafe fn showsTabBadge(&self) -> bool
pub unsafe fn showsTabBadge(&self) -> bool
When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab may optionally
display a badge indicator.
Note: This defaults to NO. Specify YES to display a badge indicator on this tab.
Sourcepub unsafe fn setShowsTabBadge(&self, shows_tab_badge: bool)
pub unsafe fn setShowsTabBadge(&self, shows_tab_badge: bool)
Setter for showsTabBadge.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for CPPointOfInterestTemplate
impl AsRef<AnyObject> for CPPointOfInterestTemplate
Sourceimpl AsRef<CPTemplate> for CPPointOfInterestTemplate
impl AsRef<CPTemplate> for CPPointOfInterestTemplate
Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<NSObject> for CPPointOfInterestTemplate
impl AsRef<NSObject> for CPPointOfInterestTemplate
Sourceimpl Borrow<AnyObject> for CPPointOfInterestTemplate
impl Borrow<AnyObject> for CPPointOfInterestTemplate
Sourceimpl Borrow<CPTemplate> for CPPointOfInterestTemplate
impl Borrow<CPTemplate> for CPPointOfInterestTemplate
Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<NSObject> for CPPointOfInterestTemplate
impl Borrow<NSObject> for CPPointOfInterestTemplate
Sourceimpl CPBarButtonProviding for CPPointOfInterestTemplate
impl CPBarButtonProviding for CPPointOfInterestTemplate
CPBarButtonProviding and CPBarButton only.CPBarButtonProviding and CPBarButton only.leadingNavigationBarButtons.CPBarButtonProviding and CPBarButton only.CPBarButtonProviding and CPBarButton only.trailingNavigationBarButtons.Sourceunsafe fn backButton(&self) -> Option<Retained<CPBarButton>>
unsafe fn backButton(&self) -> Option<Retained<CPBarButton>>
CPBarButtonProviding and CPBarButton only.Sourceunsafe fn setBackButton(&self, back_button: Option<&CPBarButton>)
unsafe fn setBackButton(&self, back_button: Option<&CPBarButton>)
CPBarButtonProviding and CPBarButton only.backButton.Sourceimpl ClassType for CPPointOfInterestTemplate
impl ClassType for CPPointOfInterestTemplate
Sourceconst NAME: &'static str = "CPPointOfInterestTemplate"
const NAME: &'static str = "CPPointOfInterestTemplate"
Sourcetype Super = CPTemplate
type Super = CPTemplate
Sourcetype ThreadKind = dyn MainThreadOnly
type ThreadKind = dyn MainThreadOnly
Sourceimpl Debug for CPPointOfInterestTemplate
impl Debug for CPPointOfInterestTemplate
Sourceimpl Deref for CPPointOfInterestTemplate
impl Deref for CPPointOfInterestTemplate
Sourceimpl Hash for CPPointOfInterestTemplate
impl Hash for CPPointOfInterestTemplate
Sourceimpl Message for CPPointOfInterestTemplate
impl Message for CPPointOfInterestTemplate
Sourceimpl NSCoding for CPPointOfInterestTemplate
impl NSCoding for CPPointOfInterestTemplate
Sourceimpl NSObjectProtocol for CPPointOfInterestTemplate
impl NSObjectProtocol for CPPointOfInterestTemplate
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl RefEncode for CPPointOfInterestTemplate
impl RefEncode for CPPointOfInterestTemplate
Sourceconst ENCODING_REF: Encoding = <CPTemplate as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <CPTemplate as ::objc2::RefEncode>::ENCODING_REF
impl DowncastTarget for CPPointOfInterestTemplate
impl Eq for CPPointOfInterestTemplate