pub struct CPRouteInformation { /* private fields */ }CPRouteInformation only.Expand description
CPRouteInformation describes information pertaining to a route that is necessary for rerouting.
See also Apple’s documentation
Implementations
Sourceimpl CPRouteInformation
impl CPRouteInformation
Sourcepub unsafe fn initWithManeuvers_laneGuidances_currentManeuvers_currentLaneGuidance_tripTravelEstimates_maneuverTravelEstimates(
this: Allocated<Self>,
maneuvers: &NSArray<CPManeuver>,
lane_guidances: &NSArray<CPLaneGuidance>,
current_maneuvers: &NSArray<CPManeuver>,
current_lane_guidance: &CPLaneGuidance,
trip_travel_estimates: &CPTravelEstimates,
maneuver_travel_estimates: &CPTravelEstimates,
) -> Retained<Self>
Available on crate features CPLaneGuidance and CPManeuver and CPTravelEstimates only.
pub unsafe fn initWithManeuvers_laneGuidances_currentManeuvers_currentLaneGuidance_tripTravelEstimates_maneuverTravelEstimates( this: Allocated<Self>, maneuvers: &NSArray<CPManeuver>, lane_guidances: &NSArray<CPLaneGuidance>, current_maneuvers: &NSArray<CPManeuver>, current_lane_guidance: &CPLaneGuidance, trip_travel_estimates: &CPTravelEstimates, maneuver_travel_estimates: &CPTravelEstimates, ) -> Retained<Self>
CPLaneGuidance and CPManeuver and CPTravelEstimates only.Initialize a CPRouteInformation object with maneuvers, lane guidances, the current maneuvers, the current lane guidance, and trip and current maneuver travel estimates.
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourcepub unsafe fn maneuvers(&self) -> Retained<NSArray<CPManeuver>>
Available on crate feature CPManeuver only.
pub unsafe fn maneuvers(&self) -> Retained<NSArray<CPManeuver>>
CPManeuver only.maneuvers is an array of CPManeuver objects, each describes a single maneuver.
This property is not atomic.
Safety
This might not be thread-safe.
Sourcepub unsafe fn laneGuidances(&self) -> Retained<NSArray<CPLaneGuidance>>
Available on crate feature CPLaneGuidance only.
pub unsafe fn laneGuidances(&self) -> Retained<NSArray<CPLaneGuidance>>
CPLaneGuidance only.laneGuidances is an array of CPLaneGuidance objects, each describes a single lane guidance.
This property is not atomic.
Safety
This might not be thread-safe.
Sourcepub unsafe fn currentManeuvers(&self) -> Retained<NSArray<CPManeuver>>
Available on crate feature CPManeuver only.
pub unsafe fn currentManeuvers(&self) -> Retained<NSArray<CPManeuver>>
CPManeuver only.currentManeuvers is an array of CPManeuver objects, describing the current maneuvers.
This property is not atomic.
Safety
This might not be thread-safe.
Sourcepub unsafe fn currentLaneGuidance(&self) -> Retained<CPLaneGuidance>
Available on crate feature CPLaneGuidance only.
pub unsafe fn currentLaneGuidance(&self) -> Retained<CPLaneGuidance>
CPLaneGuidance only.currentLaneGuidance is a CPLaneGuidance object, describing the current lane guidance.
This property is not atomic.
Safety
This might not be thread-safe.
Sourcepub unsafe fn tripTravelEstimates(&self) -> Retained<CPTravelEstimates>
Available on crate feature CPTravelEstimates only.
pub unsafe fn tripTravelEstimates(&self) -> Retained<CPTravelEstimates>
CPTravelEstimates only.tripTravelEstimates is a CPTravelEstimates object, describing the travel estimates for the current trip.
This property is not atomic.
Safety
This might not be thread-safe.
Sourcepub unsafe fn maneuverTravelEstimates(&self) -> Retained<CPTravelEstimates>
Available on crate feature CPTravelEstimates only.
pub unsafe fn maneuverTravelEstimates(&self) -> Retained<CPTravelEstimates>
CPTravelEstimates only.maneuverTravelEstimates is a CPTravelEstimates object, describing the travel estimates for the first maneuver in the list of current maneuvers.
This property is not atomic.
Safety
This might not be thread-safe.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for CPRouteInformation
impl AsRef<AnyObject> for CPRouteInformation
Sourceimpl AsRef<CPRouteInformation> for CPRouteInformation
impl AsRef<CPRouteInformation> for CPRouteInformation
Sourceimpl AsRef<NSObject> for CPRouteInformation
impl AsRef<NSObject> for CPRouteInformation
Sourceimpl Borrow<AnyObject> for CPRouteInformation
impl Borrow<AnyObject> for CPRouteInformation
Sourceimpl Borrow<NSObject> for CPRouteInformation
impl Borrow<NSObject> for CPRouteInformation
Sourceimpl ClassType for CPRouteInformation
impl ClassType for CPRouteInformation
Sourceconst NAME: &'static str = "CPRouteInformation"
const NAME: &'static str = "CPRouteInformation"
Sourcetype ThreadKind = <<CPRouteInformation as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<CPRouteInformation as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for CPRouteInformation
impl Debug for CPRouteInformation
Sourceimpl Deref for CPRouteInformation
impl Deref for CPRouteInformation
Sourceimpl Hash for CPRouteInformation
impl Hash for CPRouteInformation
Sourceimpl Message for CPRouteInformation
impl Message for CPRouteInformation
Sourceimpl NSObjectProtocol for CPRouteInformation
impl NSObjectProtocol for CPRouteInformation
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref