CPTemplate

Struct CPTemplate 

pub struct CPTemplate { /* private fields */ }
Available on crate feature CPTemplate only.
Abstract superclass for a template object.

See also Apple’s documentation

Implementations

Source

impl CPTemplate

pub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>

Any custom data or an object associated with this template can be stored in this property.

pub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)

Setter for userInfo.

Safety

user_info should be of the correct type.

pub unsafe fn tabTitle(&self) -> Option<Retained<NSString>>

When this template is the first template displayed in a CPTabBarTemplate'stab, the tab will inherit the tabTitlespecified in this template.

Note: If no tabTitleis specified, the tab will inherit the template’s title, if any.

Note: Your template should specify either a tabSystemItemOR both a tabImageand tabTitle.

pub unsafe fn setTabTitle(&self, tab_title: Option<&NSString>)

Setter for tabTitle.

This is copied when set.

pub unsafe fn tabImage(&self) -> Option<Retained<UIImage>>

Available on crate feature objc2-ui-kit only.

When this template is the first template displayed in a CPTabBarTemplate'stab, the tab will inherit the image specified in this template. If a tabSystemItem is also specified, tabImage will take precedence.

Note: Your template should specify either a tabSystemItemOR both a tabImageand tabTitle.

pub unsafe fn setTabImage(&self, tab_image: Option<&UIImage>)

Available on crate feature objc2-ui-kit only.

Setter for tabImage.

pub unsafe fn tabSystemItem(&self) -> UITabBarSystemItem

Available on crate feature objc2-ui-kit only.

When this template is the first template displayed in a CPTabBarTemplate'stab, the tab will inherit the system image AND system title specified in this template.

Note: Your template should specify either a tabSystemItemOR both a tabImageand tabTitle.

pub unsafe fn setTabSystemItem(&self, tab_system_item: UITabBarSystemItem)

Available on crate feature objc2-ui-kit only.

Setter for tabSystemItem.

pub unsafe fn showsTabBadge(&self) -> bool

When this template is the first template displayed in a CPTabBarTemplate'stab, the tab may optionally display a badge indicator.

Note: This defaults to NO. Specify YES to display a badge indicator on this tab.

pub unsafe fn setShowsTabBadge(&self, shows_tab_badge: bool)

Setter for showsTabBadge.

Source

impl CPTemplate

Methods declared on superclass NSObject.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}