pub struct CPWindow { /* private fields */ }CPWindow and objc2-ui-kit only.Expand description
CPWindowis the main window for content presented on the car screen.
See also Apple’s documentation
Implementations
Sourceimpl CPWindow
impl CPWindow
Sourcepub unsafe fn mapButtonSafeAreaLayoutGuide(&self) -> Retained<UILayoutGuide>
pub unsafe fn mapButtonSafeAreaLayoutGuide(&self) -> Retained<UILayoutGuide>
mapButtonSafeAreaLayoutGuidecan be used to layout content that appears above the map buttons presented on the map template.
Sourcepub unsafe fn windowScene(&self) -> Option<Retained<UIWindowScene>>
pub unsafe fn windowScene(&self) -> Option<Retained<UIWindowScene>>
windowSceneis not available for CPWindow’s
Sourcepub unsafe fn setWindowScene(&self, window_scene: Option<&UIWindowScene>)
pub unsafe fn setWindowScene(&self, window_scene: Option<&UIWindowScene>)
Setter for windowScene.
This is a weak property.
Sourcepub unsafe fn templateApplicationScene(
&self,
) -> Option<Retained<CPTemplateApplicationScene>>
Available on crate feature CPTemplateApplicationScene only.
pub unsafe fn templateApplicationScene( &self, ) -> Option<Retained<CPTemplateApplicationScene>>
CPTemplateApplicationScene only.back-referenceto the CPTemplateApplicationScene containing this CPWindow
Sourcepub unsafe fn setTemplateApplicationScene(
&self,
template_application_scene: Option<&CPTemplateApplicationScene>,
)
Available on crate feature CPTemplateApplicationScene only.
pub unsafe fn setTemplateApplicationScene( &self, template_application_scene: Option<&CPTemplateApplicationScene>, )
CPTemplateApplicationScene only.Setter for templateApplicationScene.
This is a weak property.
Sourceimpl CPWindow
Methods declared on superclass UIWindow.
impl CPWindow
Methods declared on superclass UIWindow.
pub unsafe fn initWithWindowScene( this: Allocated<Self>, window_scene: &UIWindowScene, ) -> Retained<Self>
pub unsafe fn initWithFrame( this: Allocated<Self>, frame: CGRect, ) -> Retained<Self>
objc2-core-foundation only.pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Methods from Deref<Target = UIWindow>
pub fn windowScene(&self) -> Option<Retained<UIWindowScene>>
Sourcepub fn setWindowScene(&self, window_scene: Option<&UIWindowScene>)
pub fn setWindowScene(&self, window_scene: Option<&UIWindowScene>)
Setter for windowScene.
This is a weak property.
pub fn canResizeToFitContent(&self) -> bool
Sourcepub fn setCanResizeToFitContent(&self, can_resize_to_fit_content: bool)
pub fn setCanResizeToFitContent(&self, can_resize_to_fit_content: bool)
Setter for canResizeToFitContent.
pub fn isKeyWindow(&self) -> bool
pub fn canBecomeKeyWindow(&self) -> bool
pub fn becomeKeyWindow(&self)
pub fn resignKeyWindow(&self)
pub fn makeKeyWindow(&self)
pub fn makeKeyAndVisible(&self)
Sourcepub fn safeAreaAspectFitLayoutGuide(&self) -> Retained<UILayoutGuide>
pub fn safeAreaAspectFitLayoutGuide(&self) -> Retained<UILayoutGuide>
This layout guide is designed specifically for full-screen media content, and attaching constraints from deep in the window’s view hierarchy will raise an exception.
This guide provides a layout area for placing media content of a given aspect ratio (width over height) such that the content will be completely visible within the window.
Compared to the standard safeAreaLayoutGuide on a view, this guide takes into account the aspect ratio of the content, allowing it the maximum size within the window’s
true safe area, including the actual shape of the screen when that is the only factor contributing to the safe area. The rect defined by this guide will be centered within the
window.
This layout guide should only be used for fixed aspect ratio content that is intended to fill the window (such as image or video content) and is not a replacement for the
standard safeAreaLayoutGuide on each UIView which should be used for most content layout. The safeAreaAspectFitLayoutGuide should only be used with views
that are direct subviews of, or very close descendants of, the guide’s window. Creating constraints from this layout guide to views deeper in the view hierarchy or across
views owned by child view controllers can significantly degrade performance and possibly raise an exception. Additionally, the safe area insets added by child view
controllers will not be reflected in these cases. For anything other than full-screen/window media content, the standard safeAreaLayoutGuide on UIView should be used.
Methods from Deref<Target = UIView>
pub fn isUserInteractionEnabled(&self) -> bool
Sourcepub fn setUserInteractionEnabled(&self, user_interaction_enabled: bool)
pub fn setUserInteractionEnabled(&self, user_interaction_enabled: bool)
Setter for isUserInteractionEnabled.
pub fn tag(&self) -> isize
pub fn canBecomeFocused(&self) -> bool
pub fn isFocused(&self) -> bool
Sourcepub fn focusGroupIdentifier(&self) -> Option<Retained<NSString>>
pub fn focusGroupIdentifier(&self) -> Option<Retained<NSString>>
The identifier of the focus group that this view belongs to. If this is nil, subviews inherit their superview’s focus group.
Sourcepub fn setFocusGroupIdentifier(&self, focus_group_identifier: Option<&NSString>)
pub fn setFocusGroupIdentifier(&self, focus_group_identifier: Option<&NSString>)
Setter for focusGroupIdentifier.
This is copied when set.
Sourcepub fn focusGroupPriority(&self) -> isize
pub fn focusGroupPriority(&self) -> isize
The priority this item has in its focus group. The higher the priority, the more likely it is to get picked when focus moves into this group. Note: this method can only be used to increase an item’s priority, not decrease it. For example if an item is currently selected, the actual priority of this item will be determined by MAX(focusGroupPriority, UIFocusGroupPrioritySelected).
Sourcepub fn setFocusGroupPriority(&self, focus_group_priority: isize)
pub fn setFocusGroupPriority(&self, focus_group_priority: isize)
Setter for focusGroupPriority.
pub fn semanticContentAttribute(&self) -> UISemanticContentAttribute
Sourcepub fn setSemanticContentAttribute(
&self,
semantic_content_attribute: UISemanticContentAttribute,
)
pub fn setSemanticContentAttribute( &self, semantic_content_attribute: UISemanticContentAttribute, )
Setter for semanticContentAttribute.
pub fn effectiveUserInterfaceLayoutDirection( &self, ) -> UIUserInterfaceLayoutDirection
pub fn isMultipleTouchEnabled(&self) -> bool
Sourcepub fn setMultipleTouchEnabled(&self, multiple_touch_enabled: bool)
pub fn setMultipleTouchEnabled(&self, multiple_touch_enabled: bool)
Setter for isMultipleTouchEnabled.
pub fn isExclusiveTouch(&self) -> bool
Sourcepub fn setExclusiveTouch(&self, exclusive_touch: bool)
pub fn setExclusiveTouch(&self, exclusive_touch: bool)
Setter for isExclusiveTouch.
pub fn autoresizesSubviews(&self) -> bool
Sourcepub fn setAutoresizesSubviews(&self, autoresizes_subviews: bool)
pub fn setAutoresizesSubviews(&self, autoresizes_subviews: bool)
Setter for autoresizesSubviews.
pub fn autoresizingMask(&self) -> UIViewAutoresizing
Sourcepub fn setAutoresizingMask(&self, autoresizing_mask: UIViewAutoresizing)
pub fn setAutoresizingMask(&self, autoresizing_mask: UIViewAutoresizing)
Setter for autoresizingMask.
pub fn sizeToFit(&self)
pub fn superview(&self) -> Option<Retained<UIView>>
pub fn subviews(&self) -> Retained<NSArray<UIView>>
pub fn window(&self) -> Option<Retained<UIWindow>>
pub fn removeFromSuperview(&self)
pub fn insertSubview_atIndex(&self, view: &UIView, index: isize)
pub fn exchangeSubviewAtIndex_withSubviewAtIndex( &self, index1: isize, index2: isize, )
pub fn addSubview(&self, view: &UIView)
pub fn insertSubview_belowSubview( &self, view: &UIView, sibling_subview: &UIView, )
pub fn insertSubview_aboveSubview( &self, view: &UIView, sibling_subview: &UIView, )
pub fn bringSubviewToFront(&self, view: &UIView)
pub fn sendSubviewToBack(&self, view: &UIView)
pub fn didAddSubview(&self, subview: &UIView)
pub fn willRemoveSubview(&self, subview: &UIView)
pub fn willMoveToSuperview(&self, new_superview: Option<&UIView>)
pub fn didMoveToSuperview(&self)
pub fn willMoveToWindow(&self, new_window: Option<&UIWindow>)
pub fn didMoveToWindow(&self)
pub fn isDescendantOfView(&self, view: &UIView) -> bool
pub fn viewWithTag(&self, tag: isize) -> Option<Retained<UIView>>
Sourcepub fn setNeedsUpdateProperties(&self)
pub fn setNeedsUpdateProperties(&self)
Call to manually request a properties update for the view. Multiple requests may be coalesced into a single update alongside the next layout pass.
Sourcepub fn updateProperties(&self)
pub fn updateProperties(&self)
Override point for subclasses to update properties of this view.
Never call this method directly; use setNeedsUpdateProperties to schedule an update.
Sourcepub fn updatePropertiesIfNeeded(&self)
pub fn updatePropertiesIfNeeded(&self)
Forces an immediate properties update for this view (and its view controller, if applicable) and any subviews, including any view controllers or views in its subtree.
pub fn setNeedsLayout(&self)
pub fn layoutIfNeeded(&self)
pub fn layoutSubviews(&self)
pub fn preservesSuperviewLayoutMargins(&self) -> bool
Sourcepub fn setPreservesSuperviewLayoutMargins(
&self,
preserves_superview_layout_margins: bool,
)
pub fn setPreservesSuperviewLayoutMargins( &self, preserves_superview_layout_margins: bool, )
Setter for preservesSuperviewLayoutMargins.
pub fn insetsLayoutMarginsFromSafeArea(&self) -> bool
Sourcepub fn setInsetsLayoutMarginsFromSafeArea(
&self,
insets_layout_margins_from_safe_area: bool,
)
pub fn setInsetsLayoutMarginsFromSafeArea( &self, insets_layout_margins_from_safe_area: bool, )
Setter for insetsLayoutMarginsFromSafeArea.
pub fn layoutMarginsDidChange(&self)
pub fn safeAreaInsetsDidChange(&self)
pub fn layoutMarginsGuide(&self) -> Retained<UILayoutGuide>
Sourcepub fn readableContentGuide(&self) -> Retained<UILayoutGuide>
pub fn readableContentGuide(&self) -> Retained<UILayoutGuide>
This content guide provides a layout area that you can use to place text and related content whose width should generally be constrained to a size that is easy for the user to read. This guide provides a centered region that you can place content within to get this behavior for this view.
pub fn safeAreaLayoutGuide(&self) -> Retained<UILayoutGuide>
pub fn setNeedsDisplay(&self)
pub fn clipsToBounds(&self) -> bool
Sourcepub fn setClipsToBounds(&self, clips_to_bounds: bool)
pub fn setClipsToBounds(&self, clips_to_bounds: bool)
Setter for clipsToBounds.
pub fn backgroundColor(&self) -> Option<Retained<UIColor>>
Sourcepub fn setBackgroundColor(&self, background_color: Option<&UIColor>)
pub fn setBackgroundColor(&self, background_color: Option<&UIColor>)
Setter for backgroundColor.
This is copied when set.
pub fn isOpaque(&self) -> bool
pub fn clearsContextBeforeDrawing(&self) -> bool
Sourcepub fn setClearsContextBeforeDrawing(&self, clears_context_before_drawing: bool)
pub fn setClearsContextBeforeDrawing(&self, clears_context_before_drawing: bool)
Setter for clearsContextBeforeDrawing.
pub fn isHidden(&self) -> bool
pub fn contentMode(&self) -> UIViewContentMode
Sourcepub fn setContentMode(&self, content_mode: UIViewContentMode)
pub fn setContentMode(&self, content_mode: UIViewContentMode)
Setter for contentMode.
pub fn maskView(&self) -> Option<Retained<UIView>>
Sourcepub fn setMaskView(&self, mask_view: Option<&UIView>)
pub fn setMaskView(&self, mask_view: Option<&UIView>)
Setter for maskView.
pub fn tintColor(&self) -> Option<Retained<UIColor>>
Sourcepub unsafe fn setTintColor(&self, tint_color: Option<&UIColor>)
pub unsafe fn setTintColor(&self, tint_color: Option<&UIColor>)
pub fn tintAdjustmentMode(&self) -> UIViewTintAdjustmentMode
Sourcepub fn setTintAdjustmentMode(
&self,
tint_adjustment_mode: UIViewTintAdjustmentMode,
)
pub fn setTintAdjustmentMode( &self, tint_adjustment_mode: UIViewTintAdjustmentMode, )
Setter for tintAdjustmentMode.
pub fn tintColorDidChange(&self)
pub fn updateConstraintsIfNeeded(&self)
pub fn updateConstraints(&self)
pub fn needsUpdateConstraints(&self) -> bool
pub fn setNeedsUpdateConstraints(&self)
pub fn translatesAutoresizingMaskIntoConstraints(&self) -> bool
Sourcepub fn setTranslatesAutoresizingMaskIntoConstraints(
&self,
translates_autoresizing_mask_into_constraints: bool,
)
pub fn setTranslatesAutoresizingMaskIntoConstraints( &self, translates_autoresizing_mask_into_constraints: bool, )
Setter for translatesAutoresizingMaskIntoConstraints.
pub fn viewForBaselineLayout(&self) -> Retained<UIView>
pub fn viewForFirstBaselineLayout(&self) -> Retained<UIView>
pub fn viewForLastBaselineLayout(&self) -> Retained<UIView>
pub fn invalidateIntrinsicContentSize(&self)
pub fn layoutGuides(&self) -> Retained<NSArray<UILayoutGuide>>
pub fn addLayoutGuide(&self, layout_guide: &UILayoutGuide)
pub fn removeLayoutGuide(&self, layout_guide: &UILayoutGuide)
pub fn hasAmbiguousLayout(&self) -> bool
pub fn exerciseAmbiguityInLayout(&self)
pub fn restorationIdentifier(&self) -> Option<Retained<NSString>>
Sourcepub fn setRestorationIdentifier(
&self,
restoration_identifier: Option<&NSString>,
)
pub fn setRestorationIdentifier( &self, restoration_identifier: Option<&NSString>, )
Setter for restorationIdentifier.
This is copied when set.
Sourcepub unsafe fn encodeRestorableStateWithCoder(&self, coder: &NSCoder)
pub unsafe fn encodeRestorableStateWithCoder(&self, coder: &NSCoder)
Safety
coder possibly has further requirements.
Sourcepub unsafe fn decodeRestorableStateWithCoder(&self, coder: &NSCoder)
pub unsafe fn decodeRestorableStateWithCoder(&self, coder: &NSCoder)
Safety
coder possibly has further requirements.
pub fn snapshotViewAfterScreenUpdates( &self, after_updates: bool, ) -> Option<Retained<UIView>>
pub fn overrideUserInterfaceStyle(&self) -> UIUserInterfaceStyle
Sourcepub fn setOverrideUserInterfaceStyle(
&self,
override_user_interface_style: UIUserInterfaceStyle,
)
pub fn setOverrideUserInterfaceStyle( &self, override_user_interface_style: UIUserInterfaceStyle, )
Setter for overrideUserInterfaceStyle.
Sourcepub fn appliedContentSizeCategoryLimitsDescription(&self) -> Retained<NSString>
pub fn appliedContentSizeCategoryLimitsDescription(&self) -> Retained<NSString>
Will return a string with a log of all the superviews of this view, alongside with what content size category each view has and if that view has limits applied. This is for debugging purposes only.
pub fn traitOverrides(&self) -> Retained<ProtocolObject<dyn UITraitOverrides>>
Sourcepub fn updateTraitsIfNeeded(&self)
pub fn updateTraitsIfNeeded(&self)
Forces an immediate trait update for this view (and its view controller, if applicable) and any subviews, including any view controllers or views in its subtree. Any trait change callbacks are sent synchronously.
Methods from Deref<Target = UIResponder>
pub fn nextResponder(&self) -> Option<Retained<UIResponder>>
pub fn canBecomeFirstResponder(&self) -> bool
pub fn becomeFirstResponder(&self) -> bool
pub fn canResignFirstResponder(&self) -> bool
pub fn resignFirstResponder(&self) -> bool
pub fn isFirstResponder(&self) -> bool
Sourcepub unsafe fn canPerformAction_withSender(
&self,
action: Sel,
sender: Option<&AnyObject>,
) -> bool
pub unsafe fn canPerformAction_withSender( &self, action: Sel, sender: Option<&AnyObject>, ) -> bool
Safety
actionmust be a valid selector.sendershould be of the correct type.
Sourcepub unsafe fn targetForAction_withSender(
&self,
action: Sel,
sender: Option<&AnyObject>,
) -> Option<Retained<AnyObject>>
pub unsafe fn targetForAction_withSender( &self, action: Sel, sender: Option<&AnyObject>, ) -> Option<Retained<AnyObject>>
Safety
actionmust be a valid selector.sendershould be of the correct type.
pub fn undoManager(&self) -> Option<Retained<NSUndoManager>>
pub fn editingInteractionConfiguration( &self, ) -> UIEditingInteractionConfiguration
pub fn inputView(&self) -> Option<Retained<UIView>>
pub fn inputAccessoryView(&self) -> Option<Retained<UIView>>
pub fn textInputContextIdentifier(&self) -> Option<Retained<NSString>>
pub fn reloadInputViews(&self)
pub fn userActivity(&self) -> Option<Retained<NSUserActivity>>
Sourcepub fn setUserActivity(&self, user_activity: Option<&NSUserActivity>)
pub fn setUserActivity(&self, user_activity: Option<&NSUserActivity>)
Setter for userActivity.
pub fn updateUserActivityState(&self, activity: &NSUserActivity)
pub fn restoreUserActivityState(&self, activity: &NSUserActivity)
Sourcepub unsafe fn captureTextFromCamera(&self, sender: Option<&AnyObject>)
pub unsafe fn captureTextFromCamera(&self, sender: Option<&AnyObject>)
Safety
sender should be of the correct type.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<UIResponder> for CPWindow
impl AsRef<UIResponder> for CPWindow
Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl Borrow<UIResponder> for CPWindow
impl Borrow<UIResponder> for CPWindow
Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl CALayerDelegate for CPWindow
impl CALayerDelegate for CPWindow
fn displayLayer(&self, layer: &CALayer)
fn layerWillDraw(&self, layer: &CALayer)
fn layoutSublayersOfLayer(&self, layer: &CALayer)
fn actionForLayer_forKey( &self, layer: &CALayer, event: &NSString, ) -> Option<Retained<ProtocolObject<dyn CAAction>>>
Sourceimpl ClassType for CPWindow
impl ClassType for CPWindow
Sourceconst NAME: &'static str = "CPWindow"
const NAME: &'static str = "CPWindow"
Sourcetype ThreadKind = <<CPWindow as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<CPWindow as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl NSObjectProtocol for CPWindow
impl NSObjectProtocol for CPWindow
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl RefEncode for CPWindow
impl RefEncode for CPWindow
Sourceconst ENCODING_REF: Encoding = <UIWindow as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <UIWindow as ::objc2::RefEncode>::ENCODING_REF
Sourceimpl UIAppearance for CPWindow
impl UIAppearance for CPWindow
fn appearance(mtm: MainThreadMarker) -> Retained<Self>
Sourceunsafe fn appearanceWhenContainedInInstancesOfClasses(
container_types: &NSArray<AnyClass>,
mtm: MainThreadMarker,
) -> Retained<Self>
unsafe fn appearanceWhenContainedInInstancesOfClasses( container_types: &NSArray<AnyClass>, mtm: MainThreadMarker, ) -> Retained<Self>
fn appearanceForTraitCollection( trait: &UITraitCollection, mtm: MainThreadMarker, ) -> Retained<Self>
Sourceunsafe fn appearanceForTraitCollection_whenContainedInInstancesOfClasses(
trait: &UITraitCollection,
container_types: &NSArray<AnyClass>,
mtm: MainThreadMarker,
) -> Retained<Self>
unsafe fn appearanceForTraitCollection_whenContainedInInstancesOfClasses( trait: &UITraitCollection, container_types: &NSArray<AnyClass>, mtm: MainThreadMarker, ) -> Retained<Self>
Sourceimpl UIDynamicItem for CPWindow
impl UIDynamicItem for CPWindow
Sourcefn collisionBoundsType(&self) -> UIDynamicItemCollisionBoundsType
fn collisionBoundsType(&self) -> UIDynamicItemCollisionBoundsType
Sourceimpl UIFocusEnvironment for CPWindow
impl UIFocusEnvironment for CPWindow
Sourcefn preferredFocusEnvironments(
&self,
) -> Retained<NSArray<ProtocolObject<dyn UIFocusEnvironment>>>
fn preferredFocusEnvironments( &self, ) -> Retained<NSArray<ProtocolObject<dyn UIFocusEnvironment>>>
Sourcefn parentFocusEnvironment(
&self,
) -> Option<Retained<ProtocolObject<dyn UIFocusEnvironment>>>
fn parentFocusEnvironment( &self, ) -> Option<Retained<ProtocolObject<dyn UIFocusEnvironment>>>
Sourcefn focusItemContainer(
&self,
) -> Option<Retained<ProtocolObject<dyn UIFocusItemContainer>>>
fn focusItemContainer( &self, ) -> Option<Retained<ProtocolObject<dyn UIFocusItemContainer>>>
Sourcefn setNeedsFocusUpdate(&self)
fn setNeedsFocusUpdate(&self)
[[UIFocusSystem focusSystemForEnvironment:self] requestFocusUpdateToEnvironment:self];Sourcefn updateFocusIfNeeded(&self)
fn updateFocusIfNeeded(&self)
[[UIFocusSystem focusSystemForEnvironment:self] updateFocusIfNeeded];.Sourcefn shouldUpdateFocusInContext(&self, context: &UIFocusUpdateContext) -> bool
fn shouldUpdateFocusInContext(&self, context: &UIFocusUpdateContext) -> bool
Sourcefn soundIdentifierForFocusUpdateInContext(
&self,
context: &UIFocusUpdateContext,
) -> Option<Retained<NSString>>
fn soundIdentifierForFocusUpdateInContext( &self, context: &UIFocusUpdateContext, ) -> Option<Retained<NSString>>
Sourceimpl UIFocusItem for CPWindow
impl UIFocusItem for CPWindow
Sourcefn canBecomeFocused(&self) -> bool
fn canBecomeFocused(&self) -> bool
Sourcefn focusGroupPriority(&self) -> isize
fn focusGroupPriority(&self) -> isize
Sourcefn focusItemDeferralMode(&self) -> UIFocusItemDeferralMode
fn focusItemDeferralMode(&self) -> UIFocusItemDeferralMode
UIFocusItemDeferralModeNever, the focus deferral will not be enabled again
after the user engagement timeout has expired if this item is currently focused and programmatic focus updates pointing
to this item will be executed immediatly. If it returns UIFocusItemDeferralModeAlways focus will always be deferred
when this item is supposed to be focused.
Does nothing when focus deferral is not supported on the platform.Sourcefn isTransparentFocusItem(&self) -> bool
fn isTransparentFocusItem(&self) -> bool
Sourceimpl UIFocusItemContainer for CPWindow
impl UIFocusItemContainer for CPWindow
Sourcefn coordinateSpace(&self) -> Retained<ProtocolObject<dyn UICoordinateSpace>>
fn coordinateSpace(&self) -> Retained<ProtocolObject<dyn UICoordinateSpace>>
Sourceimpl UIResponderStandardEditActions for CPWindow
impl UIResponderStandardEditActions for CPWindow
Sourceunsafe fn makeTextWritingDirectionLeftToRight(&self, sender: Option<&AnyObject>)
unsafe fn makeTextWritingDirectionLeftToRight(&self, sender: Option<&AnyObject>)
Sourceunsafe fn makeTextWritingDirectionRightToLeft(&self, sender: Option<&AnyObject>)
unsafe fn makeTextWritingDirectionRightToLeft(&self, sender: Option<&AnyObject>)
Sourceimpl UITraitEnvironment for CPWindow
impl UITraitEnvironment for CPWindow
fn traitCollection(&self) -> Retained<UITraitCollection>
Sourcefn traitCollectionDidChange(
&self,
previous_trait_collection: Option<&UITraitCollection>,
)
fn traitCollectionDidChange( &self, previous_trait_collection: Option<&UITraitCollection>, )
impl DowncastTarget for CPWindow
impl Eq for CPWindow
impl UIAppearanceContainer for CPWindow
impl UICoordinateSpace for CPWindow