pub struct CPAlertTemplate { /* private fields */ }CPAlertTemplate and CPTemplate only.Expand description
CPAlertTemplaterepresents a modal alert that must be dismissed with a button press
before the user may return to using the app.
See also Apple’s documentation
Implementations
Sourceimpl CPAlertTemplate
impl CPAlertTemplate
Sourcepub unsafe fn initWithTitleVariants_actions(
this: Allocated<Self>,
title_variants: &NSArray<NSString>,
actions: &NSArray<CPAlertAction>,
) -> Retained<Self>
Available on crate feature CPAlertAction only.
pub unsafe fn initWithTitleVariants_actions( this: Allocated<Self>, title_variants: &NSArray<NSString>, actions: &NSArray<CPAlertAction>, ) -> Retained<Self>
CPAlertAction only.Initialize a
CPAlertTemplateby specifying a list of title variants and at least one action.
Parameter titleVariants: An array of strings, ordered longest to shortest. The template will display
the longest string that fits in the available space on the current size of the car screen,
dropping down to shorter strings as necessary.
Parameter actions: An array of alert actions to display in this alert template. You must specify at
least one action.
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
pub unsafe fn titleVariants(&self) -> Retained<NSArray<NSString>>
Sourcepub unsafe fn maximumActionCount(mtm: MainThreadMarker) -> NSUInteger
pub unsafe fn maximumActionCount(mtm: MainThreadMarker) -> NSUInteger
Maximum number of action buttons that may appear in any
CPAlertTemplate.If you add more than this number of buttons, only the most recently-added buttons
(up to this count) will be kept.
pub unsafe fn actions(&self) -> Retained<NSArray<CPAlertAction>>
CPAlertAction only.Methods from Deref<Target = CPTemplate>
Sourcepub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>
pub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>
Any custom data or an object associated with this template can be stored in this property.
Sourcepub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)
pub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)
Sourcepub unsafe fn tabTitle(&self) -> Option<Retained<NSString>>
pub unsafe fn tabTitle(&self) -> Option<Retained<NSString>>
When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the
tabTitlespecified in this template.
Note: If no
tabTitleis specified, the tab will inherit the template’s title, if any.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabTitle(&self, tab_title: Option<&NSString>)
pub unsafe fn setTabTitle(&self, tab_title: Option<&NSString>)
Sourcepub unsafe fn tabImage(&self) -> Option<Retained<UIImage>>
Available on crate feature objc2-ui-kit only.
pub unsafe fn tabImage(&self) -> Option<Retained<UIImage>>
objc2-ui-kit only.When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the image specified in this template. If a tabSystemItem is also specified, tabImage will take precedence.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabImage(&self, tab_image: Option<&UIImage>)
Available on crate feature objc2-ui-kit only.
pub unsafe fn setTabImage(&self, tab_image: Option<&UIImage>)
objc2-ui-kit only.Setter for tabImage.
Sourcepub unsafe fn tabSystemItem(&self) -> UITabBarSystemItem
Available on crate feature objc2-ui-kit only.
pub unsafe fn tabSystemItem(&self) -> UITabBarSystemItem
objc2-ui-kit only.When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the system image AND system title specified in this template.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabSystemItem(&self, tab_system_item: UITabBarSystemItem)
Available on crate feature objc2-ui-kit only.
pub unsafe fn setTabSystemItem(&self, tab_system_item: UITabBarSystemItem)
objc2-ui-kit only.Setter for tabSystemItem.
Sourcepub unsafe fn showsTabBadge(&self) -> bool
pub unsafe fn showsTabBadge(&self) -> bool
When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab may optionally
display a badge indicator.
Note: This defaults to NO. Specify YES to display a badge indicator on this tab.
Sourcepub unsafe fn setShowsTabBadge(&self, shows_tab_badge: bool)
pub unsafe fn setShowsTabBadge(&self, shows_tab_badge: bool)
Setter for showsTabBadge.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for CPAlertTemplate
impl AsRef<AnyObject> for CPAlertTemplate
Sourceimpl AsRef<CPAlertTemplate> for CPAlertTemplate
impl AsRef<CPAlertTemplate> for CPAlertTemplate
Sourceimpl AsRef<CPTemplate> for CPAlertTemplate
impl AsRef<CPTemplate> for CPAlertTemplate
Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<NSObject> for CPAlertTemplate
impl AsRef<NSObject> for CPAlertTemplate
Sourceimpl Borrow<AnyObject> for CPAlertTemplate
impl Borrow<AnyObject> for CPAlertTemplate
Sourceimpl Borrow<CPTemplate> for CPAlertTemplate
impl Borrow<CPTemplate> for CPAlertTemplate
Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<NSObject> for CPAlertTemplate
impl Borrow<NSObject> for CPAlertTemplate
Sourceimpl ClassType for CPAlertTemplate
impl ClassType for CPAlertTemplate
Sourceconst NAME: &'static str = "CPAlertTemplate"
const NAME: &'static str = "CPAlertTemplate"
Sourcetype Super = CPTemplate
type Super = CPTemplate
Sourcetype ThreadKind = dyn MainThreadOnly
type ThreadKind = dyn MainThreadOnly
Sourceimpl Debug for CPAlertTemplate
impl Debug for CPAlertTemplate
Sourceimpl Deref for CPAlertTemplate
impl Deref for CPAlertTemplate
Sourceimpl Hash for CPAlertTemplate
impl Hash for CPAlertTemplate
Sourceimpl Message for CPAlertTemplate
impl Message for CPAlertTemplate
Sourceimpl NSCoding for CPAlertTemplate
impl NSCoding for CPAlertTemplate
Sourceimpl NSObjectProtocol for CPAlertTemplate
impl NSObjectProtocol for CPAlertTemplate
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl NSSecureCoding for CPAlertTemplate
impl NSSecureCoding for CPAlertTemplate
Sourceimpl PartialEq for CPAlertTemplate
impl PartialEq for CPAlertTemplate
Sourceimpl RefEncode for CPAlertTemplate
impl RefEncode for CPAlertTemplate
Sourceconst ENCODING_REF: Encoding = <CPTemplate as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <CPTemplate as ::objc2::RefEncode>::ENCODING_REF
impl DowncastTarget for CPAlertTemplate
impl Eq for CPAlertTemplate