CPNavigationSession

Struct CPNavigationSession 

pub struct CPNavigationSession { /* private fields */ }
Available on crate feature CPNavigationSession only.
CPNavigationSessionrepresents the active navigation session. A CPNavigationSessionwill be created for you when calling startNavigationSessionForTrip: on CYMapTemplate

See also Apple’s documentation

Implementations

Source

impl CPNavigationSession

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>

pub unsafe fn pauseTripForReason_description( &self, reason: CPTripPauseReason, description: Option<&NSString>, )

Pause the current trip.

Parameter reason: The reason navigation was paused.

Parameter description: An optional description of the pause reason. If nil,a system-provided string will be used.

pub unsafe fn pauseTripForReason_description_turnCardColor( &self, reason: CPTripPauseReason, description: Option<&NSString>, turn_card_color: Option<&UIColor>, )

Available on crate feature objc2-ui-kit only.

Pause the current trip.

Parameter reason: The reason navigation was paused.

Parameter description: An optional description of the pause reason. If nil,a system-provided string will be used.

Parameter turnCardColor: An optional color of the pause card. If nil,will fallback to the guidanceBackgroundColoron CPMapTemplate.If no color is specified there, will default to a system-provided color.

pub unsafe fn resumeTripWithUpdatedRouteInformation( &self, route_information: &CPRouteInformation, )

Available on crate feature CPRouteInformation only.

Resume the current trip with updated route information

Parameter routeInformation: The updated route information for the current trip

pub unsafe fn finishTrip(&self)

Finish the trip.

pub unsafe fn cancelTrip(&self)

Cancel the trip.

pub unsafe fn upcomingManeuvers(&self) -> Retained<NSArray<CPManeuver>>

Available on crate feature CPManeuver only.

The next maneuvers that should be performed to follow the current route. Multiple maneuvers are displayed simultaneously, however the system may limit the number of maneuvers shown at the same time.

pub unsafe fn setUpcomingManeuvers( &self, upcoming_maneuvers: &NSArray<CPManeuver>, )

Available on crate feature CPManeuver only.

Setter for upcomingManeuvers.

This is copied when set.

pub unsafe fn currentLaneGuidance(&self) -> Option<Retained<CPLaneGuidance>>

Available on crate feature CPLaneGuidance only.

The current lane guidance to be used for navigation metdata. Must be set to nil if there is no current lane guidance. CPLaneGuidances set here must first be added to the session using addLaneGuidances:

pub unsafe fn setCurrentLaneGuidance( &self, current_lane_guidance: Option<&CPLaneGuidance>, )

Available on crate feature CPLaneGuidance only.

Setter for currentLaneGuidance.

This is copied when set.

pub unsafe fn addManeuvers(&self, maneuvers: &NSArray<CPManeuver>)

Available on crate feature CPManeuver only.

Use this method to add CPManeuvers in chronological order to the navigation session. The application must provide as many maneuvers as possible, as soon as they are available. All maneuvers set in upcomingManeuvers must be first added using this method.

pub unsafe fn addLaneGuidances(&self, lane_guidances: &NSArray<CPLaneGuidance>)

Available on crate feature CPLaneGuidance only.

Use this method to add CPLaneGuidances in chronological order to the navigation session. CPLaneGuidance objects must be added as soon as they are available.

pub unsafe fn currentRoadNameVariants(&self) -> Retained<NSArray<NSString>>

Set this property with variants of the current road name. From most to least verbose.

pub unsafe fn setCurrentRoadNameVariants( &self, current_road_name_variants: &NSArray<NSString>, )

Setter for currentRoadNameVariants.

This is copied when set.

pub unsafe fn maneuverState(&self) -> CPManeuverState

Available on crate feature CPManeuver only.

Set this property with the current maneuver state based on how close the maneuver is.

pub unsafe fn setManeuverState(&self, maneuver_state: CPManeuverState)

Available on crate feature CPManeuver only.

Setter for maneuverState.

pub unsafe fn trip(&self) -> Retained<CPTrip>

Available on crate feature CPTrip only.

The trip associated with this navigation session.

pub unsafe fn updateTravelEstimates_forManeuver( &self, estimates: &CPTravelEstimates, maneuver: &CPManeuver, )

Available on crate features CPManeuver and CPTravelEstimates only.

Update the travel estimates for the active navigation session and maneuver.

Parameter estimates: The updated travel estimates.

Parameter maneuver: The maneuver pertaining to this update.

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}