pub struct CPPointOfInterest { /* private fields */ }CPPointOfInterest only.Expand description
Implementations
Sourceimpl CPPointOfInterest
impl CPPointOfInterest
Sourcepub unsafe fn initWithLocation_title_subtitle_summary_detailTitle_detailSubtitle_detailSummary_pinImage_selectedPinImage(
this: Allocated<Self>,
location: &MKMapItem,
title: &NSString,
subtitle: Option<&NSString>,
summary: Option<&NSString>,
detail_title: Option<&NSString>,
detail_subtitle: Option<&NSString>,
detail_summary: Option<&NSString>,
pin_image: Option<&UIImage>,
selected_pin_image: Option<&UIImage>,
) -> Retained<Self>
Available on crate features objc2-map-kit and objc2-ui-kit only.
pub unsafe fn initWithLocation_title_subtitle_summary_detailTitle_detailSubtitle_detailSummary_pinImage_selectedPinImage( this: Allocated<Self>, location: &MKMapItem, title: &NSString, subtitle: Option<&NSString>, summary: Option<&NSString>, detail_title: Option<&NSString>, detail_subtitle: Option<&NSString>, detail_summary: Option<&NSString>, pin_image: Option<&UIImage>, selected_pin_image: Option<&UIImage>, ) -> Retained<Self>
objc2-map-kit and objc2-ui-kit only.Initializes a point of interest to be used with
CPPointOfInterestTemplate.
Parameter location: Location indicator use by map annotations.
Parameter title: Primary title for this point of interest.
Parameter subtitle: Optional: Secondary title for this point of interest.
Parameter summary: Optional: Summary text for this point of interest.
Parameter detailTitle: Optional: Title to be used when POI detail card is visible.
Parameter detailSubtitle: Optional: Subtitle to be used when POI detail card is visible.
Parameter detailSummary: Optional: Summary text to be used when POI detail card is visible.
Parameter pinImage: Optional: a custom unselected map annotation image.
Parameter selectedPinImage: Optional: a custom selected map annotation image.
Note: When providing an image, your app should provide a
UIImagethat is display-ready. If necessary for the image, provide
light and dark styles by using an asset from your asset catalog, prepared with light and dark styles
or by using
UIImageAssetto combine two
UIImageinstances into a single image with
both styles.
CPPointOfInterest instances appear on the Point of Interest map view as both selectable items in the table view overlay and as map annotations.
To properly size your pin images, your app should size them to the display scale of the car screen. See -[CPInterfaceController carTraitCollection].
Sourcepub unsafe fn initWithLocation_title_subtitle_summary_detailTitle_detailSubtitle_detailSummary_pinImage(
this: Allocated<Self>,
location: &MKMapItem,
title: &NSString,
subtitle: Option<&NSString>,
summary: Option<&NSString>,
detail_title: Option<&NSString>,
detail_subtitle: Option<&NSString>,
detail_summary: Option<&NSString>,
pin_image: Option<&UIImage>,
) -> Retained<Self>
Available on crate features objc2-map-kit and objc2-ui-kit only.
pub unsafe fn initWithLocation_title_subtitle_summary_detailTitle_detailSubtitle_detailSummary_pinImage( this: Allocated<Self>, location: &MKMapItem, title: &NSString, subtitle: Option<&NSString>, summary: Option<&NSString>, detail_title: Option<&NSString>, detail_subtitle: Option<&NSString>, detail_summary: Option<&NSString>, pin_image: Option<&UIImage>, ) -> Retained<Self>
objc2-map-kit and objc2-ui-kit only.Initializes a point of interest to be used with
CPPointOfInterestTemplate.
Parameter location: Location indicator use by map annotations.
Parameter title: Primary title for this point of interest.
Parameter subtitle: Optional: Secondary title for this point of interest.
Parameter summary: Optional: Summary text for this point of interest.
Parameter detailTitle: Optional: Title to be used when POI detail card is visible.
Parameter detailSubtitle: Optional: Subtitle to be used when POI detail card is visible.
Parameter detailSummary: Optional: Summary text to be used when POI detail card is visible.
Parameter pinImage: Optional: a custom map annotation image.
Note: When providing an image, your app should provide a
UIImagethat is display-ready. If necessary for the image, provide
light and dark styles by using an asset from your asset catalog, prepared with light and dark styles
or by using
UIImageAssetto combine two
UIImageinstances into a single image with
both styles.
CPPointOfInterest instances appear on the Point of Interest map view as both selectable items in the table view overlay and as map annotations.
To properly size your pin images, your app should size them to the display scale of the car screen. See -[CPInterfaceController carTraitCollection].
Sourcepub unsafe fn pinImageSize() -> CGSize
Available on crate feature objc2-core-foundation only.
pub unsafe fn pinImageSize() -> CGSize
objc2-core-foundation only.If you provide a custom image for this point of interest, the unselected image must be this size. Any image larger than this size will be resized.
Sourcepub unsafe fn selectedPinImageSize() -> CGSize
Available on crate feature objc2-core-foundation only.
pub unsafe fn selectedPinImageSize() -> CGSize
objc2-core-foundation only.If you provide a custom image for this point of interest, the selected image must be this size. Any image larger than this size will be resized.
Sourcepub unsafe fn location(&self) -> Retained<MKMapItem>
Available on crate feature objc2-map-kit only.
pub unsafe fn location(&self) -> Retained<MKMapItem>
objc2-map-kit only.Location associated with this point of interest.
Sourcepub unsafe fn setLocation(&self, location: &MKMapItem)
Available on crate feature objc2-map-kit only.
pub unsafe fn setLocation(&self, location: &MKMapItem)
objc2-map-kit only.Setter for location.
Sourcepub unsafe fn subtitle(&self) -> Option<Retained<NSString>>
pub unsafe fn subtitle(&self) -> Option<Retained<NSString>>
Subtitle for this point of interest.
Sourcepub unsafe fn setSubtitle(&self, subtitle: Option<&NSString>)
pub unsafe fn setSubtitle(&self, subtitle: Option<&NSString>)
Sourcepub unsafe fn summary(&self) -> Option<Retained<NSString>>
pub unsafe fn summary(&self) -> Option<Retained<NSString>>
Summary text for this point of interest.
Sourcepub unsafe fn setSummary(&self, summary: Option<&NSString>)
pub unsafe fn setSummary(&self, summary: Option<&NSString>)
Sourcepub unsafe fn detailTitle(&self) -> Option<Retained<NSString>>
pub unsafe fn detailTitle(&self) -> Option<Retained<NSString>>
Title to be used when POI detail card is visible.
Note: If not provided, the point of interest will fall back to displaying
title.
Sourcepub unsafe fn setDetailTitle(&self, detail_title: Option<&NSString>)
pub unsafe fn setDetailTitle(&self, detail_title: Option<&NSString>)
Setter for detailTitle.
This is copied when set.
Sourcepub unsafe fn detailSubtitle(&self) -> Option<Retained<NSString>>
pub unsafe fn detailSubtitle(&self) -> Option<Retained<NSString>>
Subtitle to be used when POI detail card is visible.
Note: If not provided, the point of interest will fall back to displaying
subtitle.
Sourcepub unsafe fn setDetailSubtitle(&self, detail_subtitle: Option<&NSString>)
pub unsafe fn setDetailSubtitle(&self, detail_subtitle: Option<&NSString>)
Setter for detailSubtitle.
This is copied when set.
Sourcepub unsafe fn detailSummary(&self) -> Option<Retained<NSString>>
pub unsafe fn detailSummary(&self) -> Option<Retained<NSString>>
Summary text to be used when POI detail card is visible.
Note: If not provided, the point of interest will fall back to displaying
summary.
Sourcepub unsafe fn setDetailSummary(&self, detail_summary: Option<&NSString>)
pub unsafe fn setDetailSummary(&self, detail_summary: Option<&NSString>)
Setter for detailSummary.
This is copied when set.
Sourcepub unsafe fn pinImage(&self) -> Option<Retained<UIImage>>
Available on crate feature objc2-ui-kit only.
pub unsafe fn pinImage(&self) -> Option<Retained<UIImage>>
objc2-ui-kit only.Image used for map view unselected annotations.
To properly size your pin image, your app should size them to the display scale of the car screen. See -[CPInterfaceController carTraitCollection].
Sourcepub unsafe fn setPinImage(&self, pin_image: Option<&UIImage>)
Available on crate feature objc2-ui-kit only.
pub unsafe fn setPinImage(&self, pin_image: Option<&UIImage>)
objc2-ui-kit only.Setter for pinImage.
Sourcepub unsafe fn selectedPinImage(&self) -> Option<Retained<UIImage>>
Available on crate feature objc2-ui-kit only.
pub unsafe fn selectedPinImage(&self) -> Option<Retained<UIImage>>
objc2-ui-kit only.Image used for map view selected annotation.
To properly size your pin image, your app should size them to the display scale of the car screen. See -[CPInterfaceController carTraitCollection].
Sourcepub unsafe fn setSelectedPinImage(&self, selected_pin_image: Option<&UIImage>)
Available on crate feature objc2-ui-kit only.
pub unsafe fn setSelectedPinImage(&self, selected_pin_image: Option<&UIImage>)
objc2-ui-kit only.Setter for selectedPinImage.
Sourcepub unsafe fn primaryButton(&self) -> Option<Retained<CPTextButton>>
Available on crate feature CPTextButton only.
pub unsafe fn primaryButton(&self) -> Option<Retained<CPTextButton>>
CPTextButton only.Point of Interest detail card buttons.
Sourcepub unsafe fn setPrimaryButton(&self, primary_button: Option<&CPTextButton>)
Available on crate feature CPTextButton only.
pub unsafe fn setPrimaryButton(&self, primary_button: Option<&CPTextButton>)
CPTextButton only.Setter for primaryButton.
pub unsafe fn secondaryButton(&self) -> Option<Retained<CPTextButton>>
CPTextButton only.Sourcepub unsafe fn setSecondaryButton(&self, secondary_button: Option<&CPTextButton>)
Available on crate feature CPTextButton only.
pub unsafe fn setSecondaryButton(&self, secondary_button: Option<&CPTextButton>)
CPTextButton only.Setter for secondaryButton.
Sourcepub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>
pub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>
Any custom data or an object associated with this Point of Interest.
Sourcepub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)
pub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new() -> Retained<Self>
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for CPPointOfInterest
impl AsRef<AnyObject> for CPPointOfInterest
Sourceimpl AsRef<CPPointOfInterest> for CPPointOfInterest
impl AsRef<CPPointOfInterest> for CPPointOfInterest
Sourceimpl AsRef<NSObject> for CPPointOfInterest
impl AsRef<NSObject> for CPPointOfInterest
Sourceimpl Borrow<AnyObject> for CPPointOfInterest
impl Borrow<AnyObject> for CPPointOfInterest
Sourceimpl Borrow<NSObject> for CPPointOfInterest
impl Borrow<NSObject> for CPPointOfInterest
Sourceimpl ClassType for CPPointOfInterest
impl ClassType for CPPointOfInterest
Sourceconst NAME: &'static str = "CPPointOfInterest"
const NAME: &'static str = "CPPointOfInterest"
Sourcetype ThreadKind = <<CPPointOfInterest as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<CPPointOfInterest as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for CPPointOfInterest
impl Debug for CPPointOfInterest
Sourceimpl Deref for CPPointOfInterest
impl Deref for CPPointOfInterest
Sourceimpl Hash for CPPointOfInterest
impl Hash for CPPointOfInterest
Sourceimpl Message for CPPointOfInterest
impl Message for CPPointOfInterest
Sourceimpl NSCoding for CPPointOfInterest
impl NSCoding for CPPointOfInterest
Sourceimpl NSObjectProtocol for CPPointOfInterest
impl NSObjectProtocol for CPPointOfInterest
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref