pub struct CPTemplate { /* private fields */ }CPTemplate only.Expand description
Abstract superclass for a template object.
See also Apple’s documentation
Implementations
Sourceimpl CPTemplate
impl CPTemplate
Sourcepub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>
pub unsafe fn userInfo(&self) -> Option<Retained<AnyObject>>
Any custom data or an object associated with this template can be stored in this property.
Sourcepub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)
pub unsafe fn setUserInfo(&self, user_info: Option<&AnyObject>)
Sourcepub unsafe fn tabTitle(&self) -> Option<Retained<NSString>>
pub unsafe fn tabTitle(&self) -> Option<Retained<NSString>>
When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the
tabTitlespecified in this template.
Note: If no
tabTitleis specified, the tab will inherit the template’s title, if any.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabTitle(&self, tab_title: Option<&NSString>)
pub unsafe fn setTabTitle(&self, tab_title: Option<&NSString>)
Sourcepub unsafe fn tabImage(&self) -> Option<Retained<UIImage>>
Available on crate feature objc2-ui-kit only.
pub unsafe fn tabImage(&self) -> Option<Retained<UIImage>>
objc2-ui-kit only.When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the image specified in this template. If a tabSystemItem is also specified, tabImage will take precedence.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabImage(&self, tab_image: Option<&UIImage>)
Available on crate feature objc2-ui-kit only.
pub unsafe fn setTabImage(&self, tab_image: Option<&UIImage>)
objc2-ui-kit only.Setter for tabImage.
Sourcepub unsafe fn tabSystemItem(&self) -> UITabBarSystemItem
Available on crate feature objc2-ui-kit only.
pub unsafe fn tabSystemItem(&self) -> UITabBarSystemItem
objc2-ui-kit only.When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab will inherit
the system image AND system title specified in this template.
Note: Your template should specify either a
tabSystemItemOR both a
tabImageand
tabTitle.
Sourcepub unsafe fn setTabSystemItem(&self, tab_system_item: UITabBarSystemItem)
Available on crate feature objc2-ui-kit only.
pub unsafe fn setTabSystemItem(&self, tab_system_item: UITabBarSystemItem)
objc2-ui-kit only.Setter for tabSystemItem.
Sourcepub unsafe fn showsTabBadge(&self) -> bool
pub unsafe fn showsTabBadge(&self) -> bool
When this template is the first template displayed in a
CPTabBarTemplate'stab, the tab may optionally
display a badge indicator.
Note: This defaults to NO. Specify YES to display a badge indicator on this tab.
Sourcepub unsafe fn setShowsTabBadge(&self, shows_tab_badge: bool)
pub unsafe fn setShowsTabBadge(&self, shows_tab_badge: bool)
Setter for showsTabBadge.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for CPTemplate
impl AsRef<AnyObject> for CPTemplate
Sourceimpl AsRef<CPTemplate> for CPActionSheetTemplate
Available on crate feature CPActionSheetTemplate only.
impl AsRef<CPTemplate> for CPActionSheetTemplate
CPActionSheetTemplate only.Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<CPTemplate> for CPAlertTemplate
Available on crate feature CPAlertTemplate only.
impl AsRef<CPTemplate> for CPAlertTemplate
CPAlertTemplate only.Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<CPTemplate> for CPContactTemplate
Available on crate feature CPContactTemplate only.
impl AsRef<CPTemplate> for CPContactTemplate
CPContactTemplate only.Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<CPTemplate> for CPGridTemplate
Available on crate feature CPGridTemplate only.
impl AsRef<CPTemplate> for CPGridTemplate
CPGridTemplate only.Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<CPTemplate> for CPInformationTemplate
Available on crate feature CPInformationTemplate only.
impl AsRef<CPTemplate> for CPInformationTemplate
CPInformationTemplate only.Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<CPTemplate> for CPListTemplate
Available on crate feature CPListTemplate only.
impl AsRef<CPTemplate> for CPListTemplate
CPListTemplate only.Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<CPTemplate> for CPMapTemplate
Available on crate feature CPMapTemplate only.
impl AsRef<CPTemplate> for CPMapTemplate
CPMapTemplate only.Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<CPTemplate> for CPNowPlayingTemplate
Available on crate feature CPNowPlayingTemplate only.
impl AsRef<CPTemplate> for CPNowPlayingTemplate
CPNowPlayingTemplate only.Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<CPTemplate> for CPPointOfInterestTemplate
Available on crate feature CPPointOfInterestTemplate only.
impl AsRef<CPTemplate> for CPPointOfInterestTemplate
CPPointOfInterestTemplate only.Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<CPTemplate> for CPSearchTemplate
Available on crate feature CPSearchTemplate only.
impl AsRef<CPTemplate> for CPSearchTemplate
CPSearchTemplate only.Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<CPTemplate> for CPTabBarTemplate
Available on crate feature CPTabBarTemplate only.
impl AsRef<CPTemplate> for CPTabBarTemplate
CPTabBarTemplate only.Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<CPTemplate> for CPTemplate
impl AsRef<CPTemplate> for CPTemplate
Sourceimpl AsRef<CPTemplate> for CPVoiceControlTemplate
Available on crate feature CPVoiceControlTemplate only.
impl AsRef<CPTemplate> for CPVoiceControlTemplate
CPVoiceControlTemplate only.Sourcefn as_ref(&self) -> &CPTemplate
fn as_ref(&self) -> &CPTemplate
Sourceimpl AsRef<NSObject> for CPTemplate
impl AsRef<NSObject> for CPTemplate
Sourceimpl Borrow<AnyObject> for CPTemplate
impl Borrow<AnyObject> for CPTemplate
Sourceimpl Borrow<CPTemplate> for CPActionSheetTemplate
Available on crate feature CPActionSheetTemplate only.
impl Borrow<CPTemplate> for CPActionSheetTemplate
CPActionSheetTemplate only.Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<CPTemplate> for CPAlertTemplate
Available on crate feature CPAlertTemplate only.
impl Borrow<CPTemplate> for CPAlertTemplate
CPAlertTemplate only.Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<CPTemplate> for CPContactTemplate
Available on crate feature CPContactTemplate only.
impl Borrow<CPTemplate> for CPContactTemplate
CPContactTemplate only.Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<CPTemplate> for CPGridTemplate
Available on crate feature CPGridTemplate only.
impl Borrow<CPTemplate> for CPGridTemplate
CPGridTemplate only.Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<CPTemplate> for CPInformationTemplate
Available on crate feature CPInformationTemplate only.
impl Borrow<CPTemplate> for CPInformationTemplate
CPInformationTemplate only.Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<CPTemplate> for CPListTemplate
Available on crate feature CPListTemplate only.
impl Borrow<CPTemplate> for CPListTemplate
CPListTemplate only.Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<CPTemplate> for CPMapTemplate
Available on crate feature CPMapTemplate only.
impl Borrow<CPTemplate> for CPMapTemplate
CPMapTemplate only.Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<CPTemplate> for CPNowPlayingTemplate
Available on crate feature CPNowPlayingTemplate only.
impl Borrow<CPTemplate> for CPNowPlayingTemplate
CPNowPlayingTemplate only.Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<CPTemplate> for CPPointOfInterestTemplate
Available on crate feature CPPointOfInterestTemplate only.
impl Borrow<CPTemplate> for CPPointOfInterestTemplate
CPPointOfInterestTemplate only.Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<CPTemplate> for CPSearchTemplate
Available on crate feature CPSearchTemplate only.
impl Borrow<CPTemplate> for CPSearchTemplate
CPSearchTemplate only.Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<CPTemplate> for CPTabBarTemplate
Available on crate feature CPTabBarTemplate only.
impl Borrow<CPTemplate> for CPTabBarTemplate
CPTabBarTemplate only.Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<CPTemplate> for CPVoiceControlTemplate
Available on crate feature CPVoiceControlTemplate only.
impl Borrow<CPTemplate> for CPVoiceControlTemplate
CPVoiceControlTemplate only.Sourcefn borrow(&self) -> &CPTemplate
fn borrow(&self) -> &CPTemplate
Sourceimpl Borrow<NSObject> for CPTemplate
impl Borrow<NSObject> for CPTemplate
Sourceimpl ClassType for CPTemplate
impl ClassType for CPTemplate
Sourceconst NAME: &'static str = "CPTemplate"
const NAME: &'static str = "CPTemplate"
Sourcetype ThreadKind = dyn MainThreadOnly
type ThreadKind = dyn MainThreadOnly
Sourceimpl Debug for CPTemplate
impl Debug for CPTemplate
Sourceimpl Deref for CPTemplate
impl Deref for CPTemplate
Sourceimpl Hash for CPTemplate
impl Hash for CPTemplate
Sourceimpl Message for CPTemplate
impl Message for CPTemplate
Sourceimpl NSCoding for CPTemplate
impl NSCoding for CPTemplate
Sourceimpl NSObjectProtocol for CPTemplate
impl NSObjectProtocol for CPTemplate
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl NSSecureCoding for CPTemplate
impl NSSecureCoding for CPTemplate
Sourceimpl PartialEq for CPTemplate
impl PartialEq for CPTemplate
Sourceimpl RefEncode for CPTemplate
impl RefEncode for CPTemplate
Sourceconst ENCODING_REF: Encoding = <NSObject as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <NSObject as ::objc2::RefEncode>::ENCODING_REF
impl DowncastTarget for CPTemplate
impl Eq for CPTemplate