CPTemplateApplicationInstrumentClusterScene

Struct CPTemplateApplicationInstrumentClusterScene 

pub struct CPTemplateApplicationInstrumentClusterScene { /* private fields */ }
Available on crate features CPTemplateApplicationInstrumentClusterScene and objc2-ui-kit only.
Implementations

Source

impl CPTemplateApplicationInstrumentClusterScene

pub unsafe fn delegate( &self, ) -> Option<Retained<ProtocolObject<dyn CPTemplateApplicationInstrumentClusterSceneDelegate>>>

The delegate for a CPTemplateApplicationInstrumentClusterScene must conform to the CPTemplateApplicationInstrumentClusterSceneDelegate protocol.

pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn CPTemplateApplicationInstrumentClusterSceneDelegate>>, )

Setter for delegate.

pub unsafe fn instrumentClusterController( &self, ) -> Retained<CPInstrumentClusterController>

Available on crate feature CPInstrumentClusterController only.

The instrumentClusterController object for this scene.

pub unsafe fn contentStyle(&self) -> UIUserInterfaceStyle

The current content style for this scene suggested by the connected CarPlay system.

Source

impl CPTemplateApplicationInstrumentClusterScene

Methods declared on superclass UIScene.

pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn initWithSession_connectionOptions( this: Allocated<Self>, session: &UISceneSession, connection_options: &UISceneConnectionOptions, ) -> Retained<Self>

Methods from Deref<Target = UIScene>

pub fn session(&self) -> Retained<UISceneSession>

pub fn delegate(&self) -> Option<Retained<ProtocolObject<dyn UISceneDelegate>>>

pub fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn UISceneDelegate>>, )

Setter for delegate.

pub fn activationState(&self) -> UISceneActivationState

pub fn title(&self) -> Retained<NSString>

pub fn setTitle(&self, title: Option<&NSString>)

Setter for title.

This is copied when set.

pub fn subtitle(&self) -> Retained<NSString>

pub fn setSubtitle(&self, subtitle: &NSString)

Setter for subtitle.

This is copied when set.

Methods from Deref<Target = UIResponder>

pub fn nextResponder(&self) -> Option<Retained<UIResponder>>

pub fn canBecomeFirstResponder(&self) -> bool

pub fn becomeFirstResponder(&self) -> bool

pub fn canResignFirstResponder(&self) -> bool

pub fn resignFirstResponder(&self) -> bool

pub fn isFirstResponder(&self) -> bool

pub unsafe fn canPerformAction_withSender( &self, action: Sel, sender: Option<&AnyObject>, ) -> bool

Safety
  • action must be a valid selector.
  • sender should be of the correct type.
pub unsafe fn targetForAction_withSender( &self, action: Sel, sender: Option<&AnyObject>, ) -> Option<Retained<AnyObject>>

Safety
  • action must be a valid selector.
  • sender should be of the correct type.
pub fn undoManager(&self) -> Option<Retained<NSUndoManager>>

pub fn editingInteractionConfiguration( &self, ) -> UIEditingInteractionConfiguration

pub fn inputView(&self) -> Option<Retained<UIView>>

pub fn inputAccessoryView(&self) -> Option<Retained<UIView>>

pub fn textInputContextIdentifier(&self) -> Option<Retained<NSString>>

pub fn reloadInputViews(&self)

pub fn userActivity(&self) -> Option<Retained<NSUserActivity>>

pub fn setUserActivity(&self, user_activity: Option<&NSUserActivity>)

Setter for userActivity.

pub fn updateUserActivityState(&self, activity: &NSUserActivity)

pub fn restoreUserActivityState(&self, activity: &NSUserActivity)

pub unsafe fn captureTextFromCamera(&self, sender: Option<&AnyObject>)

Safety

sender should be of the correct type.

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}